//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : analog.c
// Function  : Control A/D and D/A
//---------------------------------------------------------
// Rev.01 2009.09.22 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "api.h"
#include "application.h"

//=========================
// Initialize A/D
//=========================
void Init_ADC(void)
{
    //------------------------
    // Start AD0 System Clock
    //------------------------
    MSTP.CRA.BIT._AD0    = 0;
    //----------------------------
    // Set Interrupt Request Level
    //----------------------------
    INTC.IPRF.BIT._AD0 = 5;
    //----------------------
    // System Clock Mode
    // Conversion Time = 34PCLK
    // Continuous Scan Mode (CH0-CH3)
    // CPU Trigger
    //----------------------
    AD0.ADCSR.BYTE = 0x00;
    //
    AD0.ADCSR.BIT.EXCKS    = 1; // Conversion Time = 34PCLK
    AD0.ADMOSEL.BIT.ICKSEL = 1; // Conversion Time = 34PCLK
    AD0.ADCR.BIT.CKS       = 0; // Conversion Time = 34PCLK
    AD0.ADSSTR             = 0x19;
    AD0.ADCR.BIT.TRGS    = 2; // TMR Trigger
    AD0.ADCR.BIT.EXTRGS  = 0; // TMR Trigger
    AD0.ADCR.BIT.SCANE   = 1; // Enable Scan
    AD0.ADCR.BIT.SCANS   = 0; // Scan 4-channels
    AD0.ADCR.BIT.ADSTCLR = 1; // One Shot Scan
    AD0.ADCSR.BIT.ADIE = 0;
    AD0.ADCSR.BIT.CH   = 3; // Scan CH0-CH3
    AD0.ADCSR.BIT.ADIE = 1; // Enable Interrupt
    //----------------------
    // Start A/D Conversion
    //----------------------
    AD0.ADCSR.BIT.ADST = 1;
}

//===========================
// Interrupt Handler A/D0
//===========================
void Int_Handler_AD0(void)
{
    //---------------------
    // Hook for Application
    //---------------------
    Hook_Int_Handler_AD0();
    //----------------------
    // Clear Interrupt Flag
    //----------------------
    AD0.ADCSR.BIT.ADF = 0;
}

//=========================
// Initialize D/A (Ch0/Ch1)
//=========================
void Init_DAC(void)
{
    //------------------------
    // Start DAC System Clock
    //------------------------
    MSTP.CRA.BIT._DA     = 0;
    //-------------------------
    // Enable both 2ch of DAC
    //-------------------------
    DA.DACR01.BIT.DAOE0 = 1;
    DA.DACR01.BIT.DAOE1 = 1;
    DA.DACR01.BIT.DAE   = 1;
    //----------------------
    // Set Zero in LSB 2bits
    //----------------------
    DA.DADR01T = 0x00;
}

//=====================
// Get A/D Data (10bit)
//=====================
UI16 ADC_Get_Data(UI08 ch)
{
    UI16 result;
    switch(ch)
    {
        case 0 : {result = AD0.ADDRA; break;}
        case 1 : {result = AD0.ADDRB; break;}
        case 2 : {result = AD0.ADDRC; break;}
        case 3 : {result = AD0.ADDRD; break;}
        default: {result = 0; break;}
    }
    result = result >> 6;
    return result;
}

//=====================
// Set D/A Data (10bit)
//=====================
void DAC_Set_Data(UI08 ch, UI16 data)
{
    UI08 dataH;
    UI08 dataL;

    if (data > 1023) data = 1023;
    dataH = (UI08) (data >> 2);
    dataL = (UI08) ((data << 6) & 0x00c0);

    if (ch == 0)
    {
        DA.DADR01T = dataL;
        DA.DADR0H  = dataH;
    }
    else if (ch == 1)
    {
        DA.DADR01T = dataL;
        DA.DADR1H  = dataH;
    }
}

//======================================================
// End of Program
//======================================================

