//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : dtc.c
// Function  : Control DTC
//---------------------------------------------------------
// Rev.01 2009.10.17 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "stdlib.h"
#include "api.h"

//========================
// DTC Vector Table
//========================
union dtc
{
    struct
    {
        UI08 MRA;
        UI08 MRB;
        UI16 reserved;
        UI32 SAR;
        UI32 DAR;
        UI16 CRA;
        UI16 CRB;
    } info;
    UI32 align[4];
};
typedef union dtc sDTC_INFO;

typedef struct
{
    UI08 MRA;
    UI08 MRB;
    UI16 reserved;
    UI32 SAR;
    UI32 DAR;
    UI16 CRA;
    UI16 CRB;
} sDTC_VECT;
//
#define DTC_VECT_COUNT 512
sDTC_INFO *gpDTC_VECT[DTC_VECT_COUNT] __attribute__ ((section (".dtc_vect")));
//
#define DTC_VECT_BASE 256
#define DTC_VECT_TMR0 (116 + DTC_VECT_BASE)

//=================================================
// Initialize DTC (an Example)
//=================================================
void Init_DTC(UI08 *pCH1_Cal_Wave, UI08 *pCH2_Cal_Wave, UI32 wave_length)
{
    UI32 i;
    sDTC_INFO *psDTC_INFO;
    //--------------------------
    // Start DTC System Clock
    //--------------------------
    MSTP.CRA.BIT._DTC = 0;
    //--------------------
    // Full Address Mode
    //--------------------
    SYSCR.BIT.DTCMD = 0;
    //-------------------
    // Init DTC Vector
    //-------------------
    for (i = 0; i < DTC_VECT_COUNT; i++)
    {
        gpDTC_VECT[i] = (sDTC_INFO*) 0x00000000;
    }
    //-----------------------------------------------
    // Allocate Transfer Information for TMR0 Trigger
    //-----------------------------------------------
    psDTC_INFO = (sDTC_INFO*) malloc(sizeof(sDTC_INFO) * 2); // "*2" means chain transfer
    //------------------
    // Assign DTC Vector
    //------------------
    gpDTC_VECT[DTC_VECT_TMR0] = psDTC_INFO;
    //----------------
    // Configure DTC
    //----------------
    DTC.DTCCR.BIT.RRS = 0;
    //
    psDTC_INFO[0].info.MRA = 0x48;
        // MD = 01 : Repeat Mode
        // Sz = 00 : Transfer Size, Byte
        // SM = 10 : Source Address Increment
        //      00 : reserved
    psDTC_INFO[0].info.MRB = 0x90;
        // CHNE  =  1 : Chain Transfer Enable
        // CHNS  =  0 : Always do Chain
        // DISEL =  0 : No Interrupt
        // DTS   =  1 : Source is Repeat Region
        // DM    = 00 : Destination Address Fixed
        //         00 : reserved
    psDTC_INFO[0].info.SAR = (UI32) pCH1_Cal_Wave;
    psDTC_INFO[0].info.DAR = (UI32) &(DA.DADR0H);
    psDTC_INFO[0].info.CRA = (UI16) (wave_length << 8);
    psDTC_INFO[0].info.CRB = 0x0000;
    //
    psDTC_INFO[1].info.MRA = 0x48;
        // MD = 01 : Repeat Mode
        // Sz = 00 : Transfer Size, Byte
        // SM = 10 : Source Address Increment
        //      00 : reserved
    psDTC_INFO[1].info.MRB = 0x10;
        // CHNE  =  0 : Chain Transfer Disable
        // CHNS  =  0 : Always do Chain
        // DISEL =  0 : No Interrupt
        // DTS   =  1 : Source is Repeat Region
        // DM    = 00 : Destination Address Fixed
        //         00 : reserved
    psDTC_INFO[1].info.SAR = (UI32) pCH2_Cal_Wave;
    psDTC_INFO[1].info.DAR = (UI32) &(DA.DADR1H);
    psDTC_INFO[1].info.CRA = (UI16) (wave_length << 8);
    psDTC_INFO[1].info.CRB = 0x0000;
    //-----------------------
    // Common Configuration
    //-----------------------
    DTC.DTCVBR = (void*) gpDTC_VECT;
    DTC.DTCCR.BIT.RRS = 1;
    DTC.DTCCR.BIT.RCHNE    = 1; // Enable Chain Transfer after Repeat Transfer
    INTC.CPUPCR.BIT.CPUP   = 0; // CPU has the lowest priority among DTC, DMAC, EXDMAC and CPU
    INTC.CPUPCR.BIT.DTCP   = 7; // DTC Priority
    INTC.CPUPCR.BIT.IPSETE = 0; // Disable Interrupt Priority Auto Set
    INTC.CPUPCR.BIT.CPUP   = 0; // CPU Priority
    DTC.DTCERC.BIT.CMIA0 = 1;
}

//======================================================
// End of Program
//======================================================
