//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : usb.c
// Function  : USB Control
//---------------------------------------------------------
// Rev.01 2009.08.20 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include <stdio.h>

#include "sys.h"
#include "SysMemMap.h"
#include "CatProType.h"

//==================
// Define Prototypes
//==================
void InitMemory(void);
void InitSystem(void);
void ActBulkIn(void);

//================
// Initialize USB
//================
void Init_USB(void)
{
    static UI08 usb_init_done = 0;
    //---------------------------
    // Prevent Re-Initialization
    //---------------------------
    if (usb_init_done) return;
    usb_init_done = 1;
    //-----------------------
    // Start USB System Clock
    //-----------------------
    MSTP._CRC.BIT._USB   = 0;
    //------------------------------------
    // Clear RAM Area Used by USB Controls
    //------------------------------------
    InitMemory();
    //-----------------------------------------
    // Fundamental Initialization of USB Module
    //-----------------------------------------
    InitSystem();
    ///------------------------
    // Set Interrupt Level
    ///------------------------
    INTC.IPRR.BIT._USB = 5;
}

//================
// USB Tx One Char
//================
void USB_Tx_Char(UI08 data_OUT)
{
    *dataBuffGPtr[BULKIN_IDX].writePtr = data_OUT;                              /*  Write data to ringbuffer    */

    if (dataBuffGPtr[BULKIN_IDX].writePtr >= dataBuffGPtr[BULKIN_IDX].endAriaPtr) {     /*  For boundary management */
        dataBuffGPtr[BULKIN_IDX].writePtr = (unsigned char*) dataBuffGPtr[BULKIN_IDX].beginAriaPtr;
    }
    else {                                                      /*  For normal case */
        dataBuffGPtr[BULKIN_IDX].writePtr++;
    }

    while (dataBuffGPtr[BULKIN_IDX].readPtr != dataBuffGPtr[BULKIN_IDX].writePtr)
    {
        ActBulkIn();
    }
}

//================
// USB Rx One Char
//================
UI08 USB_Rx_Char(void)
{
    volatile UI08  data_IN;

    while (dataBuffGPtr[BULKOUT_IDX].readPtr == dataBuffGPtr[BULKOUT_IDX].writePtr);

    data_IN = (UI08) *dataBuffGPtr[BULKOUT_IDX].readPtr;

    if (dataBuffGPtr[BULKOUT_IDX].readPtr >= dataBuffGPtr[BULKOUT_IDX].endAriaPtr)
    {
        /*  For boundary management */
        dataBuffGPtr[BULKOUT_IDX].readPtr = (unsigned char*) dataBuffGPtr[BULKOUT_IDX].beginAriaPtr;
    }
    else
    {
        dataBuffGPtr[BULKOUT_IDX].readPtr++;
    }

    return data_IN;
}

//===========================
// USB Interrupt Handler
//===========================
void INT_USB_Handler(void)
{
    UI08 counterLVar; /*  For branch table    */

    InterruptType   deviceSideLVar;     /*  For stored present value of interrupt flag registers    */
    GET_INTERRUPT_ENABLE                /*  For renewal interruptEnableBitsGVar */
    GET_INTERRUPT_REGISTER              /*  For renewal deviceSideLVar (Re-get the value of interrupt flag registers)   */
    deviceSideLVar.INTERRUPT.LONG &= interruptEnableBitsGVar.INTERRUPT.LONG;    /*  Filter interrupt flags (pickup interrupt with IER=1 and IFR=1)  */
    /*  Scan endpoint from 0 to 255 */
    for (counterLVar = 0;jump[counterLVar].EpInfoNum != 255;counterLVar++)
    {
        if ((deviceSideLVar.INTERRUPT.LONG & jump[counterLVar].InterruptBitStream) != 0)
        {
            /*  Judge IER=1 and IFR=1 and InterruptBitStream bit(initialy defined) = 1  */
            jump[counterLVar].CallOn(deviceSideLVar.INTERRUPT.LONG,jump[counterLVar].EpInfoNum);
            break;
        }
    }
    IRQ_CLEAR  /*  Unnecessary handler */
}

//======================================================
// End of Program
//======================================================
