//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : sys.h
// Function  : System Support (Header)
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#ifndef _SYS_H_
#define _SYS_H_

#include "config.h"
#include "iodefine.h"
#include "inlines.h"

//======================
// Define Types
//======================
typedef unsigned long  UI32;
typedef unsigned short UI16;
typedef unsigned char  UI08;
typedef   signed long  SI32;
typedef   signed short SI16;
typedef   signed char  SI08;
typedef          int   SINT;
typedef double         FLOT;

//==================
// Prototypes
//==================
//
// malloc.c
//
void *ext_sram_malloc(unsigned nbytes);
void  ext_sram_free(void *ap);
void *ext_sram_calloc(unsigned nmemb, unsigned nbytes);
void *ext_sram_realloc(void *p, unsigned nbytes);
//
// console.c
//
UI08 COM_putchar(UI08 c);
UI08 COM_getchar(void);
UI08 STUB_putchar(UI08 c);
UI08 STUB_getchar(void);
int  printf(const char *format, ...);
//
// uart.c
//
void Init_UART(void);
UI08 UART_Tx_Possible(void);
UI08 UART_Rx_Possible(void);
UI08 UART_Tx(UI08 byte);
UI08 UART_Rx(UI08 *byte);
void UART_Tx_Char(UI08 byte);
UI08 UART_Rx_Char(void);
UI08 UART_Found_Ctrl_C(void);
void Int_Handler_UART_Tx(void);
void Int_Handler_UART_Rx(void);
void Int_Handler_UART_Tx_END(void);
void Int_Handler_UART_Rx_ERR(void);
//
// usb.c
//
void Init_USB(void);
void USB_Tx_Char(UI08 data_OUT);
UI08 USB_Rx_Char(void);
void INT_USB_Handler(void);
//
// stub.c
//
void GDB_STUB_main(void);
void INT_USB_ENTRY(void);
void INT_UART_Rx_ENTRY(void);
//
void EXC_UNDEF(void);
void EXC_TRACE(void);
void INT_NMI(void);
void EXC_TRAPA_0(void);
void EXC_TRAPA_1(void);
void EXC_TRAPA_2(void);
void EXC_TRAPA_3(void);
void EXC_CPUAERR(void);
void EXC_DMAAERR(void);
void INT_UBC(void);
//
// start.S
//
void EXC_RESET(void);
//
// irq.c
//
void Init_INTC(void);
void INT_IRQ0(void);
void INT_IRQ1(void);
void INT_IRQ2(void);
void INT_IRQ3(void);
void INT_IRQ4(void);
void INT_IRQ5(void);
void INT_IRQ6(void);
void INT_IRQ7(void);
void INT_IRQ8(void);
void INT_IRQ9(void);
void INT_IRQ10(void);
void INT_IRQ11(void);
void INT_WDT(void);
void INT_AD0(void);
void INT_AD1(void);
void INT_TPU0_TGI0A(void);
void INT_TPU0_TGI0B(void);
void INT_TPU0_TGI0C(void);
void INT_TPU0_TGI0D(void);
void INT_TPU0_TGI0V(void);
void INT_TPU1_TGI1A(void);
void INT_TPU1_TGI1B(void);
void INT_TPU1_TGI1V(void);
void INT_TPU1_TGI1U(void);
void INT_TPU2_TGI2A(void);
void INT_TPU2_TGI2B(void);
void INT_TPU2_TGI2V(void);
void INT_TPU2_TGI2U(void);
void INT_TPU3_TGI3A(void);
void INT_TPU3_TGI3B(void);
void INT_TPU3_TGI3C(void);
void INT_TPU3_TGI3D(void);
void INT_TPU3_TGI3V(void);
void INT_TPU4_TGI4A(void);
void INT_TPU4_TGI4B(void);
void INT_TPU4_TGI4V(void);
void INT_TPU4_TGI4U(void);
void INT_TPU5_TGI5A(void);
void INT_TPU5_TGI5B(void);
void INT_TPU5_TGI5V(void);
void INT_TPU5_TGI5U(void);
void INT_TPU6_TGI6A(void);
void INT_TPU6_TGI6B(void);
void INT_TPU6_TGI6C(void);
void INT_TPU6_TGI6D(void);
void INT_TPU6_TGI6V(void);
void INT_TPU7_TGI7A(void);
void INT_TPU7_TGI7B(void);
void INT_TPU7_TGI7V(void);
void INT_TPU7_TGI7U(void);
void INT_TPU8_TGI8A(void);
void INT_TPU8_TGI8B(void);
void INT_TPU8_TGI8V(void);
void INT_TPU8_TGI8U(void);
void INT_TPU9_TGI9A(void);
void INT_TPU9_TGI9B(void);
void INT_TPU9_TGI9C(void);
void INT_TPU9_TGI9D(void);
void INT_TPU9_TGI9V(void);
void INT_TPU10_TGI10A(void);
void INT_TPU10_TGI10B(void);
void INT_TPU10_TGI10V(void);
void INT_TPU10_TGI10U(void);
void INT_TPU11_TGI11A(void);
void INT_TPU11_TGI11B(void);
void INT_TPU11_TGI11V(void);
void INT_TPU11_TGI11U(void);
void INT_TMR0_CMI0A(void);
void INT_TMR0_CMI0B(void);
void INT_TMR0_OV0I(void);
void INT_TMR1_CMI1A(void);
void INT_TMR1_CMI1B(void);
void INT_TMR1_OV1I(void);
void INT_TMR2_CMI2A(void);
void INT_TMR2_CMI2B(void);
void INT_TMR2_OV2I(void);
void INT_TMR3_CMI3A(void);
void INT_TMR3_CMI3B(void);
void INT_TMR3_OV3I(void);
void INT_DMAC_DMTEND0(void);
void INT_DMAC_DMTEND1(void);
void INT_DMAC_DMTEND2(void);
void INT_DMAC_DMTEND3(void);
void INT_EXDMAC_EXDMTEND0(void);
void INT_EXDMAC_EXDMTEND1(void);
void INT_EXDMAC_EXDMTEND2(void);
void INT_EXDMAC_EXDMTEND3(void);
void INT_DMAC_DMEEND0(void);
void INT_DMAC_DMEEND1(void);
void INT_DMAC_DMEEND2(void);
void INT_DMAC_DMEEND3(void);
void INT_EXDMAC_EXDMEEND0(void);
void INT_EXDMAC_EXDMEEND1(void);
void INT_EXDMAC_EXDMEEND2(void);
void INT_EXDMAC_EXDMEEND3(void);
void INT_SCI0_ERI0(void);
void INT_SCI0_RXI0(void);
void INT_SCI0_TXI0(void);
void INT_SCI0_TEI0(void);
void INT_SCI1_ERI1(void);
void INT_SCI1_RXI1(void);
void INT_SCI1_TXI1(void);
void INT_SCI1_TEI1(void);
void INT_SCI2_ERI2(void);
void INT_SCI2_RXI2(void);
void INT_SCI2_TXI2(void);
void INT_SCI2_TEI2(void);
void INT_SCI4_ERI4(void);
void INT_SCI4_RXI4(void);
void INT_SCI4_TXI4(void);
void INT_SCI4_TEI4(void);
void INT_SCI5_ERI5(void);
void INT_SCI5_RXI5(void);
void INT_SCI5_TXI5(void);
void INT_SCI5_TEI5(void);
void INT_SCI6_ERI6(void);
void INT_SCI6_RXI6(void);
void INT_SCI6_TXI6(void);
void INT_SCI6_TEI6(void);
void INT_IIC0_IICI0(void);
void INT_IIC1_IICI1(void);
void INT_TMR4_CMIA4_CMIB4(void);
void INT_TMR5_CMIA5_CMIB5(void);
void INT_TMR6_CMIA6_CMIB6(void);
void INT_TMR7_CMIA7_CMIB7(void);
void INT_USB_USBINTN0(void);
void INT_USB_USBINTN1(void);
void INT_USB_USBINTN2(void);
void INT_USB_USBINTN3(void);
void INT_USB_RESUME(void);
void EXC_RESERVED(void);
void EXC_SLEEP(void);
//
void EXC_UNDEF_Handler(void);
void EXC_TRACE_Handler(void);
void INT_NMI_Handler(void);
void EXC_TRAPA_0_Handler(void);
void EXC_TRAPA_1_Handler(void);
void EXC_TRAPA_2_Handler(void);
void EXC_TRAPA_3_Handler(void);
void EXC_CPUAERR_Handler(void);
void EXC_DMAAERR_Handler(void);
void INT_UBC_Handler(void);

#endif // _SYS_H_

//=========================================================
// End of Program
//=========================================================
