//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : main.c
// Function  : Main Routine
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "api.h"

//===========================================================
// Notes on GDB Stub
//===========================================================
// This program runs under Interrupt Control Mode = 2.
// During running the GDB STUB support routines,
// the interrupt level shown in EXR(CPU)  is set to 6,
// and it uses USB/UART interrupt with level 7.
// To prevent from running user's interrupt handlers in STUB,
// USER MUST USE YOUR INTERRUPT WITH LEVEL FROM 1 TO 6, ONLY.
//===========================================================

//===========================
// Main Routine
//===========================
int main(void)
{
    UI32 i;
    UI32 ch;
    UI32 szRX;
    UI32 szTX;
    UI08 *pBuf;
    UI08 *pDst;
    UI08 *pSrc;

    //---------------------------
    // Initialize System Hardware
    //---------------------------
    Init_USB();
    Init_CPG();
    Init_GPIO();
    Init_INTC();
    Init_TMR67();

    //----------------------------
    // Forever Loop
    //----------------------------
    while(1)
    {
        //----------------------
        // Receive Data from USB
        //----------------------
        //
        // Receive File Size
        //
        szRX = 0;
        for (i = 0; i < 4; i++)
        {
            ch = USB_Rx_Char();
            szRX = szRX + (ch << (i * 8));
        }
        //
        // Allocate Buffer
        //
        pBuf = (UI08*) malloc(sizeof(UI08) * szRX);
        if (pBuf) // OK
        {
            USB_Tx_Char(1);
        }
        else // NG
        {
            USB_Tx_Char(0);
            while(1);
        }
        //
        // Receive Main Data and Store in Video Frame Memory
        //
        pDst = pBuf;
        for (i = 0; i < szRX; i++)
        {
            ch = USB_Rx_Char();
            *pDst++ = ch;
        }
        //----------------------
        // Send Data to USB
        //----------------------
        //
        // Send Main Data from Video Frame Memory
        //
        szTX = szRX;
        pSrc = pBuf;
        for (i = 0; i < szTX; i++)
        {
            ch = *pSrc;
            *pSrc++ = 0; // erase
            USB_Tx_Char(ch);
        }
        //----------------
        // Dispose Buffer
        //----------------
        free(pBuf);
    }
    //--------------
    // End of main()
    //--------------
    return 0;
}

//===============================
// Hook for Int_Handler_TMR0_CMIA
//===============================
void Hook_Int_Handler_TMR0_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR1_CMIA
//===============================
void Hook_Int_Handler_TMR1_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR6_CMIA
//===============================
void Hook_Int_Handler_TMR6_CMIA(void)
{
    // In this routine, do nothing
}

//=========================
// Hook for Int_Handler_AD0
//=========================
void Hook_Int_Handler_AD0(void)
{
    // In this routine, do nothing
}

//======================================================
// End of Program
//======================================================

