//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : transfer_data.cpp
// Function  : Data Transfer Program Main Routine
//---------------------------------------------------------
// Rev.01 2009.10.27 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "stdafx.h"
#include <windows.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

//===================
// COM Send Data
//===================
void COM_TxData(int ch, HANDLE hCommPort)
{
    CHAR  chBuffer[128];
    BOOL  bRc;
    DWORD dwNumWritten;

    chBuffer[0] = (CHAR) ch;
    bRc = WriteFile( hCommPort,
                     chBuffer,
                     1,
                    &dwNumWritten,
                     NULL);
    if ((!bRc) || (dwNumWritten != 1))
    {
        printf("\nERROR: Can not Write to the COM Port (single byte):%lx %d\n",bRc, dwNumWritten);
        printf("GetLastError = %d\n", GetLastError());
        exit(1);
    }
}


//===================
// COM Receive Data
//===================
int COM_RxData(HANDLE hCommPort)
{
    CHAR  RdBuffer[128];
    BOOL  bRc;
    DWORD dwNumRead;

    bRc = ReadFile( hCommPort,
                    RdBuffer,
                    1,
                   &dwNumRead,
                    NULL);
    if ((!bRc) || (dwNumRead != 1))
    {
        printf("\nERROR: Can not Read from the COM Port (single byte):%lx %d\n",bRc, dwNumRead);
        printf("GetLastError = %d\n", GetLastError());
        exit(1);
    }
    //
    return (int) RdBuffer[0];
}

//===================
// COM Send Nbytes
//===================
void COM_TxData_Nbytes(DWORD bytes, CHAR *chBuff, HANDLE hCommPort)
{
    BOOL  bRc;
    DWORD dwNumWritten;

    bRc = WriteFile( hCommPort,
                     chBuff,
                     bytes,
                    &dwNumWritten,
                     NULL);
    if ((!bRc) || (dwNumWritten != bytes))
    {
        printf("\nERROR: Can not Write to the COM Port (multi byte):%lx %d\n",bRc, dwNumWritten);
        printf("GetLastError = %d\n", GetLastError());
        exit(1);
    }
}

//======================
// COM Receive Nbytes
//======================
void COM_RxData_Nbytes(DWORD bytes, CHAR *chBuff, HANDLE hCommPort)
{
    BOOL  bRc;
    DWORD dwNumRead;

    bRc = ReadFile( hCommPort,
                    chBuff,
                    bytes,
                   &dwNumRead,
                    NULL);
    if ((!bRc) || (dwNumRead != bytes))
    {
        printf("\nERROR: Can not Read from the COM Port (multi bytes):%lx %d\n",bRc, dwNumRead);
        printf("GetLastError = %d\n", GetLastError());
        exit(1);
    }
}

//====================
// Print Usage
//====================
void Print_Usage(CHAR *cMES)
{
    printf("==========================================================================\n");
    printf("Usage: transfer_data COM_PORT BPS TX_FILE_NAME RX_FILE_NAME               \n");
    printf("--------------------------------------------------------------------------\n");
    printf("    COM_PORT  : COM Port Name Connected to Target (ex.COM1, COM2,...)     \n");
    printf("    BPS       : Baud Rate (ex.115200)                                     \n");
    printf("    TX_FILE_NAME : File Name to Transfer                                  \n");
    printf("    RX_FILE_NAME : File Name to Receive                                   \n");
    printf("--------------------------------------------------------------------------\n");
    printf("Copyright 2009, 2010 (C) Takanaga Yamazaki                                \n");
    printf("==========================================================================\n");
    //
    // Quit from this Program
    //
    if (cMES == NULL)
    {
        exit(0);
    }
    else
    {
        printf("%s\n", cMES);
        exit(1);
    }
}



//============================================================
//------------------------------------------------------------
// Main Routine
//------------------------------------------------------------
//============================================================
int main(int argc, char *argv[])
{
    DWORD  i;
    CHAR   ch;
    HANDLE hCommPort;
    DCB    dcb;
    BOOL   bRc;
    DWORD  dwErrors;
    FILE  *fpTX;
    FILE  *fpRX;
    DWORD  szTX;
    DWORD  szRX;
    CHAR  *bufTX;
    CHAR  *bufRX;
    CHAR  *ptr;
    errno_t error;

    //===================================================================
    // Prologue
    //===================================================================
    //------------------------------------------------
    // Print Usage if argumant count is not completed
    //------------------------------------------------
    if (argc != 5) Print_Usage(NULL);
    //-------------------------------
    // Print Command Line Parameters
    //-------------------------------
    printf("COM Port Name  : %s\n", argv[1]);
    printf("Baud Rate      : %s\n", argv[2]);
    printf("Tx File Name   : %s\n", argv[3]);
    printf("Rx File Name   : %s\n", argv[4]);
    //------------------------------
    // Open COM Port and Check
    //------------------------------
    hCommPort = CreateFile(argv[1],
                           GENERIC_READ|GENERIC_WRITE,
                           0, // exclusive
                           NULL, // sec attr
                           OPEN_EXISTING,
                           0,             // no attributes
                           NULL);         // no template
    if (hCommPort == (HANDLE)-1)
    {
         Print_Usage("Please Check COM Port Name.");
    }
    //--------------------------
    // Set Serial Configuration
    //--------------------------
    dcb.DCBlength   = sizeof(DCB);
    if (!GetCommState(hCommPort,&dcb))
    {
        printf("ERROR: Can not get the DCB: %d\n",GetLastError());
        exit(1);
     }
    //
    dcb.BaudRate = atoi(argv[2]);
    dcb.ByteSize = 8;
    dcb.Parity   = NOPARITY;
    dcb.StopBits = ONESTOPBIT;
    //
    bRc = SetCommState(hCommPort,&dcb);
    if (!bRc)
    {
        printf("ERROR: Can not set the COM Port State rc:%lx\n",bRc);
        exit(1);
    }

    //===================================================================
    // Send Tx File
    //===================================================================
    //--------------------
    // Open Tx File
    //--------------------
    error = fopen_s(&fpTX, argv[3], "rb");
    if (error)
    {
        printf("ERROR: Can not open file : %s\n", argv[3]);
        exit(1);
    }
    //--------------------
    // Get Tx File Size
    //--------------------
    fseek(fpTX, 0, SEEK_END);
    szTX = ftell(fpTX);
    fseek(fpTX, 0, SEEK_SET);
    //--------------------
    // Tx Data Buffer
    //--------------------
    bufTX = (CHAR*) malloc(sizeof(CHAR) * szTX);
    if (bufTX == NULL)
    {
        printf("ERROR: Can not allocate work area.\n");
        exit(1);
    }
    fread(bufTX, sizeof(CHAR), szTX, fpTX);
    //----------------------
    // Send File Size to COM
    //----------------------
    for (i = 0; i < 4; i++)
    {
        ch = (szTX >> (i * 8)) & 0x00ff;
        COM_TxData(ch, hCommPort);
    }
    //-----------------
    // Receive OK or NG
    //-----------------
    ch = COM_RxData(hCommPort);
    if (ch == 0)
    {
        printf("File Size is Too Large for Target MCU.\n");
        exit(1);
    }
    //-----------------------------
    // Send Data to COM
    //-----------------------------
    printf("Now Sending Data...");
  //COM_TxData_Nbytes(szTX, bufTX, hCommPort);
    ptr = bufTX;
    for (i = 0; i < szTX; i++)
    {
        ch = *ptr++;
        COM_TxData(ch, hCommPort);
    }
    printf("Done.\n");
    //-------------------
    // Close Tx File
    //-------------------
    fclose(fpTX);
    free(bufTX);

    //===================================================================
    // Receive Rx File
    //===================================================================
    //--------------------
    // Rx Data Buffer
    //--------------------
    szRX = szTX;
    bufRX = (CHAR*) malloc(sizeof(CHAR) * szRX);
    if (bufRX == NULL)
    {
        printf("ERROR: Can not allocate work area.\n");
        exit(1);
    }
    //-----------------------------
    // Receive Data from COM
    //-----------------------------
    printf("Now Receiving Data...");
  //COM_RxData_Nbytes(szRX, bufRX, hCommPort);
    ptr = bufRX;
    for (i = 0; i < szRX; i++)
    {
        ch = COM_RxData(hCommPort);
        *ptr++ = ch;
    }
    printf("Done.\n");
    //--------------------
    // Open Rx File
    //--------------------
    error = fopen_s(&fpRX, argv[4], "wb");
    if (error)
    {
        printf("ERROR: Can not open file : %s\n", argv[4]);
        exit(1);
    }
    //---------------
    // Save the Data
    //---------------
    fwrite(bufRX, sizeof(CHAR), szRX, fpRX);
    //-------------------
    // Close Rx File
    //-------------------
    fclose(fpRX);
    free(bufRX);

    //===================================================================
    // Epilogue
    //===================================================================
    //-----------------------
    // Close the COM Port
    //-----------------------
    bRc = ClearCommError(hCommPort,&dwErrors,NULL);
    bRc = CloseHandle(hCommPort);
    if (!bRc)
    {
        printf("ERROR: Can not Close the COM Port:%lx\n",bRc);
        exit(1);
    }
    //-----------------
	// Exit Program
    //-----------------
	return 0;
}

//======================================================
// End of Program
//======================================================

