/*""FILE COMMENT""************************************************************
 *	System Name	: R0K561653D000BR USB DeviceDriver Firmware
 *	File Name	: usbmain.c
 *	Version		: 1.00-070920
 *	Contents	: 
 *	Customer	: 
 *	Model		: 
 *	Order		: 
 *	CPU			: H8SX/1653F
 *	Compiler	: ch38
 *	OS			: None
 *	Programmer	: 
 *	Notes		: 
 *****************************************************************************
 * (C)2004(2006) RENESAS TECHNOLOGY CORPORATION AND RENESAS SOLUTIONS CORPORATION,
 *	 ALL RIGHTS RESERVED.
 *****************************************************************************
 *	History		: xxxx.xx.xx : Ver.0.01 ; Release
 *""FILE COMMENT END""*******************************************************/




#ifndef SysMemMap
#include	"SysMemMap.h"
#endif	/*	SysMemMap	*/

#ifndef CatProType
#include	"CatProType.h"
#endif	/*	CatProType	*/

#include	<stdio.h>

#ifndef SetUsbInfo
#include	"SetUsbInfo.h"
#endif	/*	SetUsbInfo	*/



#ifdef HARD_VECTOR
//#pragma interrupt	(BranchOfInt)
#endif	/*	HARD_VECTOR	*/



/*	Prototype	*/
//void					BranchOfInt(void);
void                    BranchOfInt(void) __attribute__ ((interrupt_handler));
enum SetCompleteType	SetControlOutContents(ControlType*,BuffType*);
void					GetPacket(EpInfoType*,BuffType*);
void					PutPacket(EpInfoType*,BuffType*);
unsigned short			BE2ByteRead(unsigned char*);
unsigned short			LE2ByteRead(unsigned char*);
void					SetUsbModule(unsigned long  ,unsigned char );
void					ActBusReset(unsigned long  ,unsigned char );

void					USBclear(void);
extern unsigned char	BulkOutEnableFlag;
extern unsigned char	SerialInEnableFlag;


/*	Contents	*/
/***************************************************************************
Function Name	:BranchOfInt(void)
Working			:Judging interrupt flag and calling interrupt each function
Return Value	:void
Modified		:{Author : A.Ikeya	[2002.Jun.28]}
Modified		:{Author : T.Sekine[2001.Jun.29]}
Created			:{Author : T.Ishikawa[2000.Jun.09]}
***************************************************************************/
//__interrupt(vect=234) void BranchOfInt(void)
void BranchOfInt(void)
{

	unsigned char	counterLVar;		/*	For branch table	*/
	InterruptType	deviceSideLVar;		/*	For stored present value of interrupt flag registers	*/

	GET_INTERRUPT_ENABLE				/*	For renewal interruptEnableBitsGVar	*/

	GET_INTERRUPT_REGISTER				/*	For renewal deviceSideLVar (Re-get the value of interrupt flag registers)	*/

	deviceSideLVar.INTERRUPT.LONG &= interruptEnableBitsGVar.INTERRUPT.LONG;	/*	Filter interrupt flags (pickup interrupt with IER=1 and IFR=1)	*/

	for (counterLVar = 0;jump[counterLVar].EpInfoNum != 255;counterLVar++) {	/*	Scan endpoint from 0 to 255	*/

		if ((deviceSideLVar.INTERRUPT.LONG & jump[counterLVar].InterruptBitStream) != 0) {
																				/*	Judge IER=1 and IFR=1 and InterruptBitStream bit(initialy defined) = 1	*/
			jump[counterLVar].CallOn(deviceSideLVar.INTERRUPT.LONG,jump[counterLVar].EpInfoNum);
			break;
		}
	}
	IRQ_CLEAR																	/*	Unnecessary handler	*/
}



/***************************************************************************
Function Name	:GetPacket(EpInfoType*,BuffType*)
Working			:Transfering data from FIFO to RAM
Return Value	:void
Modified		:{Author : T.Ishikawa[1999.Jan.21]}
Modified		:{Author : T.Ishikawa[1998.Oct.15]}
Created			:{Author : T.Ishikawa[1997.Des.01]}
***************************************************************************/
void	GetPacket(EpInfoType*	epInfoPtr,BuffType*	memoryLPtr) {

	unsigned short	readArea = *epInfoPtr->FifoSize;			/*	For byte length in FIFO data	*/

	while (readArea != 0) {

		*memoryLPtr->writePtr = *epInfoPtr->epdrPtr;			/*	Write received data from FIFO to ringbuffer	*/

		if (memoryLPtr->writePtr >= memoryLPtr->endAriaPtr) {	/*	For boundary management	*/

			memoryLPtr->writePtr = (unsigned char*) memoryLPtr->beginAriaPtr;
		}
		else {													/*	For normal case	*/

			memoryLPtr->writePtr++;
		}
		readArea--;
	}

	READ_FINISH													/*	Set read-complete trigger	*/

}



/***************************************************************************
Function Name	:PutPacket(EpInfoType*,BuffType*)
Working			:Transfering data from RAM to FIFO
Return Value	:void
Modified		:{Author : T.Ishikawa[1999.Jan.21]}
Modified		:{Author : T.Ishikawa[1998.Oct.15]}
Modified		:{Author : T.Ishikawa[1998.Mar.11]}
Created			:{Author : T.Ishikawa[1997.Des.01]}
***************************************************************************/
void	PutPacket(EpInfoType*	epInfoPtr,BuffType*	memoryLPtr) {

	unsigned short 	writeArea = *epInfoPtr->FifoSize;									/*	For blank space in FIFO	*/

	while ((writeArea != 0) && (memoryLPtr->readPtr != memoryLPtr->writePtr)) {

		*epInfoPtr->epdrPtr = *memoryLPtr->readPtr;										/*	Write transfer data from ringbuffer to FIFO 	*/

		if (memoryLPtr->readPtr >= memoryLPtr->endAriaPtr) {							/*	For boundary management	*/

			memoryLPtr->readPtr = (unsigned char*) memoryLPtr->beginAriaPtr;
		}
		else {

			memoryLPtr->readPtr++;														/*	For normal case	*/
		}
		writeArea--;
	}

	WRITE_FINISH																		/*	Set packet-enable trigger	*/
}



/***************************************************************************
Function Name	:SetControlOutContents(ControlType*,BuffType*)
Working			:Changing transfered data from Host
Return Value	:enum SetCompleteType (COMPLETE or INCOMPLETE)
Modified		:{Author : A.Ikeya	[2002.Jun.28]}
Created			:{Author : S.Suzuki[1998.Nov.6]}
***************************************************************************/
enum SetCompleteType SetControlOutContents(ControlType* addLPtr,BuffType*	memoryLPtr) {

	if ((*EpInfo[2].FifoSize == 0x00) && (memoryLPtr->readPtr <= memoryLPtr->writePtr)) {															/*	if exist trasnfer data from host	*/

		for (;((memoryLPtr->readPtr != memoryLPtr->writePtr) && (addLPtr->beginPtr != addLPtr->endPtr));		/*	Convert data	*/
		addLPtr->beginPtr++,memoryLPtr->readPtr++) {
			*addLPtr->beginPtr = *memoryLPtr->readPtr;
		}
		return COMPLETE;
	}
	return INCOMPLETE;
}



/***************************************************************************
Function Name	:BE2ByteRead(unsigned char*)
Working			:Changing 2byte data form little endian to big endian. For example:3412 -> 1234
Return Value	:unsigned short
Created			:{Author : T.Ishikawa[1998.Mar.11]}
***************************************************************************/
unsigned short	BE2ByteRead(unsigned char*	accessLPtr) {

	register unsigned short	workLVer = (unsigned short)*accessLPtr;

	workLVer <<= 8;
	workLVer |= (unsigned short)*(++accessLPtr);
	return workLVer;
}



/***************************************************************************
Function Name	:LE2ByteRead(unsigned char*)
Working			:Changing 2byte data from big endian to little endian
Return Value	:unsigned short
Created			:{Author : T.Ishikawa[1998.Mar.11]}
***************************************************************************/
unsigned short	LE2ByteRead(unsigned char*	accessLPtr) {

	register unsigned short	workLVer = (unsigned short)*(++accessLPtr);

	workLVer <<= 8;
	workLVer |= (unsigned short)*(--accessLPtr);
	return workLVer;
}



/***************************************************************************
Function Name	:SetUsbModule(unsigned long ,unsigned char )
Working			:Initializing USB module
Return Value	:void
Created			:{Author : T.Ishikawa[2000.Jun.23]}
***************************************************************************/
void	SetUsbModule(unsigned long interruptBitStreamLVar ,unsigned char EpInfoNumberLVar) {

	RUN_USB_MODULE_2			/*	Disable USB Interface Software Reset	*/

	F_CLEAR_PLLREADY			/*	Clear PLLReady flag	*/

	SET_USB_EPINFO				/*	Set USB Information Register	*/

	SET_USB_INTERRUPT			/*	Set USB inteerupt source	*/

	GET_INTERRUPT_ENABLE		/*	Get USB interrupt flags	*/

	SET_USB_INTERRUPT_SELECT	/*	Set USB interrupt select register	*/
}



/***************************************************************************
Function Name	:ActBusReset(unsigned long ,unsigned char )
Working			:Clear FIFO in USB Bus Reset
Return Value	:void
Modified		:{Author : T.Sekine[2001.Jul.18]}
Created			:{Author : T.Ishikawa[2000.Jun.23]}
***************************************************************************/
void	ActBusReset(unsigned long interruptBitStreamLVar ,unsigned char EpInfoNumberLVar) {

	USBclear();

	F_CLEAR_BUSRESET		/*	Clear BRST-flag	*/

	CLEAR_ALL_FIFO			/*	Clear all FIFO	*/

}



/***************************************************************************
Function Name	:USBclear(unsigned long ,unsigned char )
Working			:Initializing Ringbuffer and Flag
Return Value	:void
Created			:{Author : T.Sekine[2001.Nov.21]}
Created			:{Author : T.Sekine[2001.Jun.29]}
***************************************************************************/
void USBclear(void) {

	dataBuffGPtr[0].readPtr  = &controlBeginGVar;
	dataBuffGPtr[0].writePtr = &controlBeginGVar;
	dataBuffGPtr[BULKOUT_IDX].readPtr  = &bulkoutBeginGVar;
	dataBuffGPtr[BULKOUT_IDX].writePtr = &bulkoutBeginGVar;
	dataBuffGPtr[BULKIN_IDX].readPtr  = &bulkinBeginGVar;
	dataBuffGPtr[BULKIN_IDX].writePtr = &bulkinBeginGVar;

	BulkOutEnableFlag = 0x01;
	SerialInEnableFlag = 0x01;

}

