//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : main.c
// Function  : Main Routine
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "api.h"

//===========================================================
// Notes on GDB Stub
//===========================================================
// This program runs under Interrupt Control Mode = 2.
// During running the GDB STUB support routines,
// the interrupt level shown in EXR(CPU)  is set to 6,
// and it uses USB/UART interrupt with level 7.
// To prevent from running user's interrupt handlers in STUB,
// USER MUST USE YOUR INTERRUPT WITH LEVEL FROM 1 TO 6, ONLY.
//===========================================================

//===========
// Globals
//===========
extern sDateTime gDateTime;  // Current Clock Database

//===========================
// Main Routine
//===========================
int main(void)
{
    //---------------------------
    // Initialize System Hardware
    //---------------------------
    Init_USB();
    Init_CPG();
    Init_GPIO();
    Init_INTC();
    Init_BSC();
    Init_TMR67();
    //
    Init_SPI();
    Init_RTC();
    Init_UART();
    Init_LCD1602();
    Init_ADC();
    Init_DAC();
    Init_TMR0(0);

    //--------------------
    // Test ADC and DAC
    //--------------------
    {
        UI16 out_data0;
        UI16 out_data1;
        UI16 inp_data0;
        UI16 inp_data1;
        FLOT deg;
        UI08 str0[64];
        UI08 str1[64];

        deg = 0;
        while(1)
        {
            out_data0 = 512 + 512 * _SIN_(_PI_ / 180 * deg);
            out_data1 = 512 + 512 * _COS_(_PI_ / 180 * deg);
            deg = _FMOD_(deg + 1, 360);
            //
            DAC_Set_Data(0, out_data0);
            DAC_Set_Data(1, out_data1);
            TMR_Wait_One_Tick();
            TMR_Wait_One_Tick();
            TMR_Wait_One_Tick();
            TMR_Wait_One_Tick();
            TMR_Wait_One_Tick();
            inp_data0 = ADC_Get_Data(0);
            inp_data1 = ADC_Get_Data(1);
            //
            sprintf((char*) str0, "0:O=%4d I=%4d", out_data0, inp_data0);
            sprintf((char*) str1, "1:O=%4d I=%4d", out_data1, inp_data1);
            LCD1602_Print_String(0, str0);
            LCD1602_Print_String(1, str1);
            //
            CPU_Wait_N_us(5000);
        }
    }

    //--------------
    // End of main()
    //--------------
    return 0;
}

//===============================
// Hook for Int_Handler_TMR0_CMIA
//===============================
void Hook_Int_Handler_TMR0_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR1_CMIA
//===============================
void Hook_Int_Handler_TMR1_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR6_CMIA
//===============================
void Hook_Int_Handler_TMR6_CMIA(void)
{
    //-------------
    // Key Sense
    //-------------
    KEY_Sense_Control();
}

//=========================
// Hook for Int_Handler_AD0
//=========================
void Hook_Int_Handler_AD0(void)
{
    // In this routine, do nothing
}

//======================================================
// End of Program
//======================================================

