/*""FILE COMMENT""************************************************************
 *	System Name	: R0K561653D000BR USB DeviceDriver Firmware
 *	File Name	: cattypedef.h
 *	Version		: 1.00-070920
 *	Contents	: 
 *	Customer	: 
 *	Model		: 
 *	Order		: 
 *	CPU			: H8SX/1653F
 *	Compiler	: ch38
 *	OS			: None
 *	Programmer	: 
 *	Notes		: 
 *****************************************************************************
 * (C)2004(2006) RENESAS TECHNOLOGY CORPORATION AND RENESAS SOLUTIONS CORPORATION,
 *	 ALL RIGHTS RESERVED.
 *****************************************************************************
 *	History		: xxxx.xx.xx : Ver.0.01 ; Release
 *""FILE COMMENT END""*******************************************************/


#ifndef _CATTYPEDEF_H_
#define _CATTYPEDEF_H_

enum	PresentStateType		{WAIT,TRANS_IN,TRANS_OUT,STALL};
enum	SetCompleteType			{COMPLETE,INCOMPLETE};
enum	TransModeType			{CONTROL,BULK,INTERRUPT,ISOCHRONOUS};
enum	DecControlCmdDoneType	{CTRL_COMMAND_DONE,UNKNOWN_CTRL_COMMAND};


typedef	struct BuffType {
	unsigned char*				writePtr;		/*	Write pointer for write data to buffer	*/
	unsigned char*				readPtr;		/*	Read pointer for read data from buffer	*/
	const unsigned char*		beginAriaPtr;	/*	Start of data area(buffer)	*/
	const unsigned char*		endAriaPtr;		/*	End of data area(buffer)	*/
} BuffType;



typedef	struct InterruptType {
	union {
		unsigned long	LONG;
		struct {
			unsigned char		InterruptRegister0;
			unsigned char		InterruptRegister1;
			unsigned char		InterruptRegister2;
			unsigned char		InterruptRegister3;
		} BYTE;
	} INTERRUPT;
} InterruptType;



typedef	struct LinkType {	/*	For defined relationship betweed called roution and flags	*/
	const unsigned long			InterruptBitStream;	/*	0x00000000		Interrupt flag information	*/
	const unsigned char			EpInfoNum;			/*	0				EndPoint Information	*/
	const void					(*CallOn)(unsigned long,unsigned char);		/*	Act****			Called routine	*/
} LinkType;



typedef struct EpInfoType {	/*	Informations of each EndPoints	*/
	const unsigned char			epNumber;			/*	EndPoint Number	*/
	enum TransModeType			TransMode;			/*	Transfer Type	*/
	volatile unsigned char*		FifoSize;			/*	Address of FIFO-size-register	*/
													/*	or Address of writeFifoSizeGVar[] (if FIFO-size-regisiter is not defined)	*/
	volatile unsigned char*		epdrPtr;			/*	Address of EndPoint-data-register	*/
	const unsigned char			putEnable;			/*	Bit patterns on packet transmission	*/
	const unsigned char			getFinish;			/*	Bit patterns on packet reception	*/
	const unsigned char			fifoClearEnable;	/*	Bit patterns on FIFO clearing	*/
	const unsigned char			stallEnable;		/*	Bit patterns on EndPoint stalling	*/
	enum PresentStateType		PresentState;		/*	State on USB transfer	*/
	unsigned char				MaxPacketSize;		/*	Max Size of packet	*/
} EpInfoType;



typedef	struct ControlType {	/*	For storing and rewriting received data from host device	*/
	unsigned char*				beginPtr;	/*	Start point of data rewriting	*/
	unsigned char*				endPtr;		/*	End point of data rewriting	*/
} ControlType;




typedef	union RequestType {	/*	Definition of bmRequestType	*/
	unsigned char byteVal;
	struct bitValType {
		unsigned char			d7:1;		/*	Data transfer direction	*/
		unsigned char			d65:2;		/*	Type	00:standard , 01:class , 10:vender	*/
		unsigned char			d40:5;		/*	Recipient	*/
	} bitValType;
} RequestType;



typedef	union SetupDataType {	/*	Definitions of Setup Data	*/
	unsigned char	byteVal[8];
	struct access0Type {
		RequestType				bmRequest;	/*	Characteristics of request	*/
		unsigned char			bRequest;	/*	Request number	*/
		unsigned short			wValue;		/*	Word-sized field that varies according to request	*/
		unsigned short			wIndex;		/*	Word-sized field that varies according to request	*/
											/*		This field is used in requests to specifyEndpoint or Inferface	*/
		unsigned short			wLength;	/*	Number of bytes to transfer if there is a Data stage	*/
	} access0Type;
	struct access1Type {
		unsigned char			bmRequest;	/*	Characteristics of request	*/
		unsigned char			bRequest;	/*	Request number	*/
		unsigned char			wValue_B1;	/*	Word-sized field that varies according to request	*/
		unsigned char			wValue_B2;	/*	Word-sized field that varies according to request	*/
		unsigned char			wIndex_B1;	/*	Word-sized field that varies according to request	*/
		unsigned char			wIndex_B2;	/*		This field is used in requests to specify Endpoint or Inferface	*/
		unsigned char			wLength_B1;	/*	Number of bytes to transfer if there is a Data stage	*/
		unsigned char			wLength_B2;	/*	Number of bytes to transfer if there is a Data stage	*/
	} access1Type;
} SetupDataType;



typedef	struct StringType {			/*	Definitions ablout string descripter	*/
	unsigned char				length;
	unsigned char*				d_data;
} StringType;


typedef	struct DeviceType {			/*	Definitions about device descripter	*/
	unsigned char				length;
	unsigned char*				d_data;
} DeviceType;


typedef	struct ConfigurationType {	/*	Definitions about configuration descripter	*/
	unsigned short				length;
	unsigned char*				d_data;
} ConfigurationType;


typedef struct UsbBuf {
	SetupDataType	ep0PacketGVar_buf;
	unsigned char	controlBeginGVar_buf[8];
	union {
		unsigned char	buf1[0x200];
		unsigned long	buf4[0x80];
	} buf;
} UsbBuf;


typedef struct usb_ier {					/* struct USB   */
	union {									/* IER0         */
		unsigned char BYTE;					/*  Byte Access */
		struct {							/*  Bit Access  */
			unsigned char BRST		:1;		/*   BRST       */
			unsigned char EP1_FULL	:1;		/*   EP1_FULL   */
			unsigned char EP2_TR	:1;		/*   EP2_TR     */
			unsigned char EP2_EMPTY	:1;		/*   EP2_EMPTY  */
			unsigned char SETUP_TS	:1;		/*   SETUP_TS   */
			unsigned char EP0o_TS	:1;		/*   EP0o_TS    */
			unsigned char EP0i_TR	:1;		/*   EP0i_TR    */
			unsigned char EP0i_TS	:1;		/*   EP0i_TS    */
		} BIT;								/*              */
	} IER0;									/*              */
	union {									/* IER1         */
		unsigned char BYTE;					/*  Byte Access */
		struct {							/*  Bit Access  */
			unsigned char 			:5;		/*              */
			unsigned char EP3_TR	:1;		/*   EP3_TR     */
			unsigned char EP3_TS	:1;		/*   EP3_TS     */
			unsigned char VBUSF		:1;		/*   VBUSF      */
		} BIT;								/*              */
	} IER1;									/*              */
	union {									/* IER2         */
		unsigned char BYTE;					/*  Byte Access */
		struct {							/*  Bit Access  */
			unsigned char 			:3;		/*              */
			unsigned char SURSE		:1;		/*   SURSE      */
			unsigned char CFDN		:1;		/*   CFDN       */
			unsigned char 			:1;		/*              */
			unsigned char SETCE		:1;		/*   SETCE      */
			unsigned char SETIE		:1;		/*   SETIE      */
		} BIT;								/*              */
	} IER2;									/*              */
} usb_ier;									/*              */

#endif
