/*""FILE COMMENT""************************************************************
 *	System Name	: R0K561653D000BR USB DeviceDriver Firmware
 *	File Name	: doserial.c
 *	Version		: 1.00-070920
 *	Contents	: 
 *	Customer	: 
 *	Model		: 
 *	Order		: 
 *	CPU			: H8SX/1653F
 *	Compiler	: ch38
 *	OS			: None
 *	Programmer	: 
 *	Notes		: 
 *****************************************************************************
 * (C)2004(2006) RENESAS TECHNOLOGY CORPORATION AND RENESAS SOLUTIONS CORPORATION,
 *	 ALL RIGHTS RESERVED.
 *****************************************************************************
 *	History		: xxxx.xx.xx : Ver.0.01 ; Release
 *""FILE COMMENT END""*******************************************************/




#ifndef SysMemMap
#include	"SysMemMap.h"
#endif	/*	SysMemMap	*/

#ifndef CatProType
#include	"CatProType.h"
#endif	/*	CatProType	*/



/*	Prototype	*/


unsigned char	ActSerialOut(BuffType*);
void			ActSerialIn(unsigned char);
void			WriteBulkInArea(BuffType*,char);
void			OutChar(unsigned char data);
unsigned char	InChar(void);


unsigned char SerialInEnableFlag = 0x1;



/*	Contents	*/
/***************************************************************************
Function Name	:ActSerialOut(BuffType*)
Working			:Controlling Serial-Out Transfer
				:Read transfer data from bulk-out ringbuffer , and send data to ExSerialOut()
Return Value	:void
Modified		:{Author : T.Sekine[2001.Nov.09]}
Created			:{Author : T.Sekine[2001.May.7]}
***************************************************************************/
unsigned char	ActSerialOut(BuffType* memoryLPtr) {

//	unsigned int count;
//	unsigned char i;
	unsigned char	data;

	data = *memoryLPtr->readPtr;

	if (memoryLPtr->readPtr >= memoryLPtr->endAriaPtr) {	/*	For boundary management	*/
		memoryLPtr->readPtr = (unsigned char*) memoryLPtr->beginAriaPtr;
	}
	else {
		memoryLPtr->readPtr++;
	}


/*	Control bulk-out interrupt (for flow control)	*/

	if ( BulkOutEnableFlag == 0 ) {																				/*	if disable bulk-out transfer	*/
		if ( (dataBuffGPtr[BULKOUT_IDX].writePtr >= dataBuffGPtr[BULKOUT_IDX].readPtr) & 
				( ( (dataBuffGPtr[BULKOUT_IDX].endAriaPtr + 0x1 - dataBuffGPtr[BULKOUT_IDX].beginAriaPtr) -
				(dataBuffGPtr[BULKOUT_IDX].writePtr - dataBuffGPtr[BULKOUT_IDX].readPtr) ) > (EpInfo[BULKOUT_IDX].MaxPacketSize) ) ) {
																												/*	Check blank space	*/

			SET_BULK_OUT_INT_ENABLE																				/*	Enalbe bulk-out interrupt	*/

		}
		else if ( (dataBuffGPtr[BULKOUT_IDX].writePtr < dataBuffGPtr[BULKOUT_IDX].readPtr) & 
				( (dataBuffGPtr[BULKOUT_IDX].readPtr - dataBuffGPtr[BULKOUT_IDX].writePtr) > (EpInfo[BULKOUT_IDX].MaxPacketSize) ) ) {
																												/*	Check blank space	*/

			SET_BULK_OUT_INT_ENABLE																				/*	Enable bulk-out interrupt	*/

		}
	}

	return(data);
}



/*	Contents	*/
/***************************************************************************
Function Name	:ActSerialIn(unsigned char)
Working			:Controlling Serial-In Transfer
				:Write received data to bulk-in ringbuffer
Return Value	:void
Modified		:{Author : E.Ondo[2003.Jun.10]}
Modified		:{Author : E.Ondo[2003.Oct.27]}
Modified		:{Author : A.Ikeya[2003.June.26]}
Modified		:{Author : T.Sekine[2001.Nov.27]}
Modified		:{Author : T.Sekine[2001.Nov.09]}
Created			:{Author : T.Sekine[2001.May.07]}
***************************************************************************/
void ActSerialIn(unsigned char Recieve_data)
{

	WriteBulkInArea(&dataBuffGPtr[BULKIN_IDX],Recieve_data);										/*	Write received data to ringbuffer	*/

/*	Control serial-in interrupt (flow control)	*/

	if (dataBuffGPtr[BULKIN_IDX].writePtr >= dataBuffGPtr[BULKIN_IDX].readPtr) {					/*	Check blank space	*/
		if (((dataBuffGPtr[BULKIN_IDX].endAriaPtr + 0x1 - dataBuffGPtr[BULKIN_IDX].beginAriaPtr) -	/*	blank space is nothing	*/
			(dataBuffGPtr[BULKIN_IDX].writePtr - dataBuffGPtr[BULKIN_IDX].readPtr)) <= 0x40 ) {


		}
		else {
		}
	}
	else {
		if ((dataBuffGPtr[BULKIN_IDX].readPtr - dataBuffGPtr[BULKIN_IDX].writePtr) <= 0x40) {		/*	blank space is nothing	*/


		}
		else {
		}
	}
}



/*	Contents	*/
/***************************************************************************
Function Name	:WriteBulkInArea(BuffType*,char)
Working			:Transfering data to bulk-in ringbuffer
Return Value	:void
Created			:{Author : T.Sekine[2001.May.07]}
***************************************************************************/

void WriteBulkInArea(BuffType*	memoryLPtr,char data)
{
	*memoryLPtr->writePtr = data;								/*	Write data to ringbuffer	*/

	if (memoryLPtr->writePtr >= memoryLPtr->endAriaPtr) {		/*	For boundary management	*/
		memoryLPtr->writePtr = (unsigned char*) memoryLPtr->beginAriaPtr;
	}
	else {														/*	For normal case	*/
		memoryLPtr->writePtr++;
	}
}


void OutChar(unsigned char data_OUT)
{
	*dataBuffGPtr[BULKIN_IDX].writePtr = data_OUT;								/*	Write data to ringbuffer	*/

	if (dataBuffGPtr[BULKIN_IDX].writePtr >= dataBuffGPtr[BULKIN_IDX].endAriaPtr) {		/*	For boundary management	*/
		dataBuffGPtr[BULKIN_IDX].writePtr = (unsigned char*) dataBuffGPtr[BULKIN_IDX].beginAriaPtr;
	}
	else {														/*	For normal case	*/
		dataBuffGPtr[BULKIN_IDX].writePtr++;
	}

	ActBulkIn();
}

unsigned char InChar(void)
{
	volatile unsigned char	data_IN;

	//ActBulkIn();

	while (dataBuffGPtr[BULKOUT_IDX].readPtr == dataBuffGPtr[BULKOUT_IDX].writePtr)
		;
	data_IN = *dataBuffGPtr[BULKOUT_IDX].readPtr;

	if (dataBuffGPtr[BULKOUT_IDX].readPtr >= dataBuffGPtr[BULKOUT_IDX].endAriaPtr) {	/*	For boundary management	*/
		dataBuffGPtr[BULKOUT_IDX].readPtr = (unsigned char*) dataBuffGPtr[BULKOUT_IDX].beginAriaPtr;
	}
	else {
		dataBuffGPtr[BULKOUT_IDX].readPtr++;
	}


	return data_IN;

}
