//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : bsc.c
// Function  : Configure BSC
//---------------------------------------------------------
// Rev.01 2009.09.05 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "api.h"

//===========================
// Initialize BSC
//===========================
void Init_BSC(void)
{
    //----------------------------------------
    // Configuration of External Memory Space
    //----------------------------------------
    // [BSC]
    // BCLK = 12MHz
    // CS0 : TACTSW  0x100000-0x1fffff  8bits Normal Control Wait = 7cyc (Total=10cyc)
    // CS1 : SRAM    0x200000-0x3fffff 16bits Byte Control   Wait = 0cyc (Total=2cyc)
    // CS2 : LCD1602 0x400000-0xbfffff 16bits Byte Control   Wait = 7cyc (Total=10cyc)
    //
    // [PFC]
    // /CS0  : PB0
    // /CS1  : PB1
    // /CS2  : PB2
    // /RD   : PA5
    // /RDWR : PA1
    // /LUB  : PA4
    // /LLB  : PA3
    //------------------------
    // Initialize BSC
    //------------------------
    BSC.ABWCR.WORD = 0xf9ff;  // Bus Width
    BSC.ASTCR.WORD = 0xfd00;  // Access State
    BSC.WTCRA.WORD = 0x7777;  // Wait State A
    BSC.WTCRB.WORD = 0x7777;  // Wait State B
    BSC.RDNCR.WORD = 0x0000;  // RD Timing
    BSC.CSACR.WORD = 0xfdfd;  // CS Assert
    BSC.IDLCR.WORD = 0xff00;  // Idle Control
    BSC.BCR1.WORD  = 0x0000;  // Bus Control 1
    BSC.BCR2.BYTE  = 0x02;    // Bus Control 2
    BSC.ENDIANCR.BYTE = 0x00; // Endian
    BSC.SRAMCR.WORD = 0x0600; // SRAM Control
    BSC.BROMCR.WORD = 0x0000; // Burst ROM
    BSC.MPXCR.WORD  = 0x0000; // MPX I/O
}

//======================================================
// End of Program
//======================================================

