//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : retarget.c
// Function  : System Calls to re-target
//---------------------------------------------------------
// Rev.01 2009.09.12 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <errno.h>
#include <sys/stat.h>
#include <sys/times.h>
#include <string.h>
//#undef errno
extern int errno;
#include "sys.h"

//=======================
// malloc() related
//=======================
#define HEAP_SIZE 16384 // total heap size is 16KB

//=========================================
// Low Level I/O Routines
//=========================================
//----------------
// sbrk
//----------------
caddr_t _sbrk(int incr)
{
    static char buf[HEAP_SIZE]; // keep RAM area as heap zone
    static long i = 0;
    char *ret;

    if (i + (long) incr > HEAP_SIZE) return (caddr_t)NULL;
    ret = buf + i;
    i += incr;
    return (caddr_t)ret;
}

//----------------
// _exit
//----------------
void _exit(int status)
{
    while(1);
}
//-----------------
// environ
//-----------------
char *__env[1] = { 0 };
char **environ = __env;
//-----------------
// execve
//-----------------
//int execve(char *name, char **argv, char **env)
//{
//    errno = ENOMEM;
//    return -1;
//}
//----------------
// getpid
//----------------
int _getpid(void)
{
    return 1;
}
//----------------
// isatty
//----------------
int _isatty(int file)
{
  return 1;
}
//----------------
// kill
//----------------
int _kill(int pid, int sig)
{
    errno = EINVAL;
    return -1;
}
//----------------
// times
//----------------
//int times(struct tms *buf)
//{
//  return -1;
//}

//=========================================
// Reentrant Low Level I/O Routines
//=========================================
//----------------
// _open_r
//----------------
int _open_r(void *reent, const char *file, int flags, int mode)
{
    return -1;
}
//----------------
// _close_r
//----------------
int _close_r(void *reent, int fd )
{
    return -1;
}
//----------------
// _lseek_r
//----------------
off_t _lseek_r(void *reent, int fd, off_t pos, int whence)
{
    return 0;
}
//----------------
// _read_r
//----------------
long _read_r(void *reent, int fd, void *buf, size_t cnt)
{
    UI08 *ptr;
    ptr = (UI08*) buf;

    *ptr = COM_getchar();
    return (1);
}
//----------------
// _write_r
//----------------
long _write_r(void *reent, int fd, const void *buf, size_t cnt)
{
    int todo;
    char *ptr = (char*) buf;

    for (todo = 0; todo < cnt; todo++)
    {
        COM_putchar((UI08) *ptr++);
    }
    return cnt;
}
//-----------------
// _fork_r
//-----------------
int _fork_r(void *reent)
{
    errno = EAGAIN;
    return -1;
}
//-----------------
// _wait_r
//-----------------
int _wait_r(void *reent, int *status)
{
    errno = ECHILD;
    return -1;
}
//-----------------
// _stat_r
//-----------------
int _stat_r(void *reent, const char *file, struct stat *pstat)
{
    pstat->st_mode = S_IFCHR;
    return 0;
}
//-----------------
// _fstat_r
//-----------------
int _fstat_r(void *reent, int fd, struct stat *pstat)
{
    pstat->st_mode = S_IFCHR;
    return 0;
}
//-----------------
// _link_r
//-----------------
int _link_r(void *reent, const char *old, const char *new)
{
    errno = EMLINK;
    return -1;
}
//-----------------
// _unlink_r
//-----------------
int _unlink_r(void *reent, const char *file)
{
    errno = ENOENT;
    return -1;
}

//======================================================
// End of Program
//======================================================
