//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : vect.c
// Function  : Exception Vectors
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "api.h"

//===========================
// Define Type
//===========================
typedef void (*fp) (void);

//===========================
// Vector Tables
//===========================
const fp HardwareVectors[] __attribute__ ((section (".vects"))) =
{
    EXC_RESET,     //   0 : RESET
    EXC_RESERVED,  //   1 : reserved
    EXC_RESERVED,  //   2 : reserved
    EXC_RESERVED,  //   3 : reserved
    EXC_UNDEF,     //   4 : UNDEFINED (GDB STUB)
    EXC_TRACE,     //   5 : TRACE (GDB STUB)
    EXC_RESERVED,  //   6 : reserved
    INT_NMI,       //   7 : NMI (GDB STUB)
    EXC_TRAPA_0,   //   8 : TRAP#0 (GDB STUB)
    EXC_TRAPA_1,   //   9 : TRAP#1 (GDB STUB)
    EXC_TRAPA_2,   //  10 : TRAP#2 (GDB STUB)
    EXC_TRAPA_3,   //  11 : TRAP#3  (GDB STUB)
    EXC_CPUAERR,   //  12 : CPU Address Error (GDB STUB)
    EXC_DMAAERR,   //  13 : DMA Address Error (GDB STUB)
    INT_UBC,       //  14 : UBC (GDB STUB)
    EXC_RESERVED,  //  15 : reserved
    EXC_RESERVED,  //  16 : reserved
    EXC_RESERVED,  //  17 : reserved
    EXC_SLEEP,     //  18 : SLEEP
    EXC_RESERVED,  //  19 : reserved
    EXC_RESERVED,  //  20 : reserved
    EXC_RESERVED,  //  21 : reserved
    EXC_RESERVED,  //  22 : reserved
    EXC_RESERVED,  //  23 : reserved
    EXC_RESERVED,  //  24 : User Area
    EXC_RESERVED,  //  25 : User Area
    EXC_RESERVED,  //  26 : User Area
    EXC_RESERVED,  //  27 : User Area
    EXC_RESERVED,  //  28 : User Area
    EXC_RESERVED,  //  29 : User Area
    EXC_RESERVED,  //  30 : User Area
    EXC_RESERVED,  //  31 : User Area
    EXC_RESERVED,  //  32 : User Area
    EXC_RESERVED,  //  33 : User Area
    EXC_RESERVED,  //  34 : User Area
    EXC_RESERVED,  //  35 : User Area
    EXC_RESERVED,  //  36 : User Area
    EXC_RESERVED,  //  37 : User Area
    EXC_RESERVED,  //  38 : User Area
    EXC_RESERVED,  //  39 : User Area
    EXC_RESERVED,  //  40 : User Area
    EXC_RESERVED,  //  41 : User Area
    EXC_RESERVED,  //  42 : User Area
    EXC_RESERVED,  //  43 : User Area
    EXC_RESERVED,  //  44 : User Area
    EXC_RESERVED,  //  45 : User Area
    EXC_RESERVED,  //  46 : User Area
    EXC_RESERVED,  //  47 : User Area
    EXC_RESERVED,  //  48 : User Area
    EXC_RESERVED,  //  49 : User Area
    EXC_RESERVED,  //  50 : User Area
    EXC_RESERVED,  //  51 : User Area
    EXC_RESERVED,  //  52 : User Area
    EXC_RESERVED,  //  53 : User Area
    EXC_RESERVED,  //  54 : User Area
    EXC_RESERVED,  //  55 : User Area
    EXC_RESERVED,  //  56 : User Area
    EXC_RESERVED,  //  57 : User Area
    EXC_RESERVED,  //  58 : User Area
    EXC_RESERVED,  //  59 : User Area
    EXC_RESERVED,  //  60 : User Area
    EXC_RESERVED,  //  61 : User Area
    EXC_RESERVED,  //  62 : User Area
    EXC_RESERVED,  //  63 : User Area
    INT_IRQ0,      //  64 : IRQ0
    INT_IRQ1,      //  65 : IRQ1
    INT_IRQ2,      //  66 : IRQ2
    INT_IRQ3,      //  67 : IRQ3
    INT_IRQ4,      //  68 : IRQ4
    INT_IRQ5,      //  69 : IRQ5
    INT_IRQ6,      //  70 : IRQ6
    INT_IRQ7,      //  71 : IRQ7
    INT_IRQ8,      //  72 : IRQ8
    INT_IRQ9,      //  73 : IRQ9
    INT_IRQ10,     //  74 : IRQ10
    INT_IRQ11,     //  75 : IRQ11
    EXC_RESERVED,  //  76 : Reserved
    EXC_RESERVED,  //  77 : Reserved
    EXC_RESERVED,  //  78 : Reserved
    EXC_RESERVED,  //  79 : Reserved
    EXC_RESERVED,  //  80 : Reserved
    INT_WDT,       //  81 : WDT WOVI
    EXC_RESERVED,  //  82 : Reserved
    EXC_RESERVED,  //  83 : Reserved
    EXC_RESERVED,  //  84 : Reserved
    EXC_RESERVED,  //  85 : Reserved
    INT_AD0,       //  86 : A/D_0 ADI0
    EXC_RESERVED,  //  87 : Reserved
    INT_TPU0_TGI0A, //  88 : TPU_0 TGI0A
    INT_TPU0_TGI0B, //  89 : TPU_0 TGI0B
    INT_TPU0_TGI0C, //  90 : TPU_0 TGI0C
    INT_TPU0_TGI0D, //  91 : TPU_0 TGI0D
    INT_TPU0_TGI0V, //  92 : TPU_0 TGI0V
    INT_TPU1_TGI1A, //  93 : TPU_1 TGI1A
    INT_TPU1_TGI1B, //  94 : TPU_1 TGI1B
    INT_TPU1_TGI1V, //  95 : TPU_1 TGI1V
    INT_TPU1_TGI1U, //  96 : TPU_1 TGI1U
    INT_TPU2_TGI2A, //  97 : TPU_2 TGI2A
    INT_TPU2_TGI2B, //  98 : TPU_2 TGI2B
    INT_TPU2_TGI2V, //  99 : TPU_2 TGI2V
    INT_TPU2_TGI2U, // 100 : TPU_2 TGI2U
    INT_TPU3_TGI3A, // 101 : TPU_3 TGI3A
    INT_TPU3_TGI3B, // 102 : TPU_3 TGI3B
    INT_TPU3_TGI3C, // 103 : TPU_3 TGI3C
    INT_TPU3_TGI3D, // 104 : TPU_3 TGI3D
    INT_TPU3_TGI3V, // 105 : TPU_3 TGI3V
    INT_TPU4_TGI4A, // 106 : TPU_4 TGI4A
    INT_TPU4_TGI4B, // 107 : TPU_4 TGI4B
    INT_TPU4_TGI4V, // 108 : TPU_4 TGI4V
    INT_TPU4_TGI4U, // 109 : TPU_4 TGI4U
    INT_TPU5_TGI5A, // 110 : TPU_5 TGI5A
    INT_TPU5_TGI5B, // 111 : TPU_5 TGI5B
    INT_TPU5_TGI5V, // 112 : TPU_5 TGI5V
    INT_TPU5_TGI5U, // 113 : TPU_5 TGI5U
    EXC_RESERVED,   // 114 : Reserved
    EXC_RESERVED,   // 115 : Reserved
    INT_TMR0_CMI0A, // 116 : TMR_0 CMI0A
    INT_TMR0_CMI0B, // 117 : TMR_0 CMI0B
    INT_TMR0_OV0I,  // 118 : TMR_0 OV0I
    INT_TMR1_CMI1A, // 119 : TMR_1 CMI1A
    INT_TMR1_CMI1B, // 120 : TMR_1 CMI1B
    INT_TMR1_OV1I,  // 121 : TMR_1 OV1I
    INT_TMR2_CMI2A, // 122 : TMR_2 CMI2A
    INT_TMR2_CMI2B, // 123 : TMR_2 CMI2B
    INT_TMR2_OV2I,  // 124 : TMR_2 OV2I
    INT_TMR3_CMI3A, // 125 : TMR_3 CMI3A
    INT_TMR3_CMI3B, // 126 : TMR_3 CMI3B
    INT_TMR3_OV3I,  // 127 : TMR_3 OV3I
    INT_DMAC_DMTEND0, // 128 : DMAC DMTEND0
    INT_DMAC_DMTEND1, // 129 : DMAC DMTEND1
    INT_DMAC_DMTEND2, // 130 : DMAC DMTEND2
    INT_DMAC_DMTEND3, // 131 : DMAC DMTEND3
    INT_EXDMAC_EXDMTEND0, // 132 : EXDMAC EXDMTEND0
    INT_EXDMAC_EXDMTEND1, // 133 : EXDMAC EXDMTEND1
    INT_EXDMAC_EXDMTEND2, // 134 : EXDMAC EXDMTEND2
    INT_EXDMAC_EXDMTEND3, // 135 : EXDMAC EXDMTEND3
    INT_DMAC_DMEEND0, // 136 : DMAC DMEEND0
    INT_DMAC_DMEEND1, // 137 : DMAC DMEEND1
    INT_DMAC_DMEEND2, // 138 : DMAC DMEEND2
    INT_DMAC_DMEEND3, // 139 : DMAC DMEEND3
    INT_EXDMAC_EXDMEEND0, // 140 : EXDMAC EXDMEEND0
    INT_EXDMAC_EXDMEEND1, // 141 : EXDMAC EXDMEEND1
    INT_EXDMAC_EXDMEEND2, // 142 : EXDMAC EXDMEEND2
    INT_EXDMAC_EXDMEEND3, // 143 : EXDMAC EXDMEEND3
    INT_SCI0_ERI0, // 144 : SCI_0 ERI0
    INT_SCI0_RXI0, // 145 : SCI_0 RXI0
    INT_SCI0_TXI0, // 146 : SCI_0 TXI0
    INT_SCI0_TEI0, // 147 : SCI_0 TEI0
    INT_SCI1_ERI1, // 148 : SCI_1 ERI1
    INT_SCI1_RXI1, // 149 : SCI_1 RXI1
    INT_SCI1_TXI1, // 150 : SCI_1 TXI1
    INT_SCI1_TEI1, // 151 : SCI_1 TEI1
    INT_SCI2_ERI2, // 152 : SCI_2 ERI2
    INT_SCI2_RXI2, // 153 : SCI_2 RXI2
    INT_SCI2_TXI2, // 154 : SCI_2 TXI2
    INT_SCI2_TEI2, // 155 : SCI_2 TEI2
    EXC_RESERVED,  // 156 : Reserved
    EXC_RESERVED,  // 157 : Reserved
    EXC_RESERVED,  // 158 : Reserved
    EXC_RESERVED,  // 159 : Reserved
    INT_SCI4_ERI4,     // 160 : SCI_4 ERI4
    INT_UART_Rx_ENTRY, // 161 : SCI_4 RXI4 (GDB STUB)
    INT_SCI4_TXI4,     // 162 : SCI_4 TXI4
    INT_SCI4_TEI4,     // 163 : SCI_4 TEI4
    INT_TPU6_TGI6A, // 164 : TPU_6 TGI6A
    INT_TPU6_TGI6B, // 165 : TPU_6 TGI6B
    INT_TPU6_TGI6C, // 166 : TPU_6 TGI6C
    INT_TPU6_TGI6D, // 167 : TPU_6 TGI6D
    INT_TPU6_TGI6V, // 168 : TPU_6 TGI6V
    INT_TPU7_TGI7A, // 169 : TPU_7 TGI7A
    INT_TPU7_TGI7B, // 170 : TPU_7 TGI7B
    INT_TPU7_TGI7V, // 171 : TPU_7 TGI7V
    INT_TPU7_TGI7U, // 172 : TPU_7 TGI7U
    INT_TPU8_TGI8A, // 173 : TPU_8 TGI8A
    INT_TPU8_TGI8B, // 174 : TPU_8 TGI8B
    INT_TPU8_TGI8V, // 175 : TPU_8 TGI8V
    INT_TPU8_TGI8U, // 176 : TPU_8 TGI8U
    INT_TPU9_TGI9A, // 177 : TPU_9 TGI9A
    INT_TPU9_TGI9B, // 178 : TPU_9 TGI9B
    INT_TPU9_TGI9C, // 179 : TPU_9 TGI9C
    INT_TPU9_TGI9D, // 180 : TPU_9 TGI9D
    INT_TPU9_TGI9V, // 181 : TPU_9 TGI9V
    INT_TPU10_TGI10A, // 182 : TPU_10 TGI10A
    INT_TPU10_TGI10B, // 183 : TPU_10 TGI10B
    EXC_RESERVED,     // 184 : Reserved
    EXC_RESERVED,     // 185 : Reserved
    INT_TPU10_TGI10V, // 186 : TPU_10 TGI10V
    INT_TPU10_TGI10U, // 187 : TPU_10 TGI10U
    INT_TPU11_TGI11A, // 188 : TPU_11 TGI11A
    INT_TPU11_TGI11B, // 189 : TPU_11 TGI11B
    INT_TPU11_TGI11V, // 190 : TPU_11 TGI11V
    INT_TPU11_TGI11U, // 191 : TPU_11 TGI11U
    EXC_RESERVED,  // 192 : Reserved
    EXC_RESERVED,  // 193 : Reserved
    EXC_RESERVED,  // 194 : Reserved
    EXC_RESERVED,  // 195 : Reserved
    EXC_RESERVED,  // 196 : Reserved
    EXC_RESERVED,  // 197 : Reserved
    EXC_RESERVED,  // 198 : Reserved
    EXC_RESERVED,  // 199 : Reserved
    EXC_RESERVED,  // 200 : Reserved
    EXC_RESERVED,  // 201 : Reserved
    EXC_RESERVED,  // 202 : Reserved
    EXC_RESERVED,  // 203 : Reserved
    EXC_RESERVED,  // 204 : Reserved
    EXC_RESERVED,  // 205 : Reserved
    EXC_RESERVED,  // 206 : Reserved
    EXC_RESERVED,  // 207 : Reserved
    EXC_RESERVED,  // 208 : Reserved
    EXC_RESERVED,  // 209 : Reserved
    EXC_RESERVED,  // 210 : Reserved
    EXC_RESERVED,  // 211 : Reserved
    EXC_RESERVED,  // 212 : Reserved
    EXC_RESERVED,  // 213 : Reserved
    EXC_RESERVED,  // 214 : Reserved
    EXC_RESERVED,  // 215 : Reserved
    INT_IIC0_IICI0, // 216 : IIC2_0 IICI0
    EXC_RESERVED,   // 217 : Reserved
    INT_IIC1_IICI1, // 218 : IIC2_1 IICI1
    EXC_RESERVED,   // 219 : Reserved
    INT_SCI5_RXI5, // 220 : SCI_5 RXI5
    INT_SCI5_TXI5, // 221 : SCI_5 TXI5
    INT_SCI5_ERI5, // 222 : SCI_5 ERI5
    INT_SCI5_TEI5, // 223 : SCI_5 TEI5
    INT_SCI6_RXI6, // 224 : SCI_6 RXI6
    INT_SCI6_TXI6, // 225 : SCI_6 TXI6
    INT_SCI6_ERI6, // 226 : SCI_6 ERI6
    INT_SCI6_TEI6, // 227 : SCI_6 TEI6
    INT_TMR4_CMIA4_CMIB4, // 228 : TMR_4 CMIA4 CMIB4
    INT_TMR5_CMIA5_CMIB5, // 229 : TMR_5 CMIA5 CMIB5
    INT_TMR6_CMIA6_CMIB6, // 230 : TMR_6 CMIA6 CMIB6
    INT_TMR7_CMIA7_CMIB7, // 231 : TMR_7 CMIA7 CMIB7
    INT_USB_USBINTN0, // 232 : USB USBINTN0
    INT_USB_USBINTN1, // 233 : USB USBINTN1
    INT_USB_ENTRY,    // 234 : USB USBINTN2 (GDB STUB)
    INT_USB_USBINTN3, // 235 : USB USBINTN3
    EXC_RESERVED,  // 236 : Reserved
    INT_AD1,       // 237 : A/D_1 ADI1
    INT_USB_RESUME,// 238 : USB Resume
    EXC_RESERVED,  // 239 : Reserved
    EXC_RESERVED,  // 240 : Reserved
    EXC_RESERVED,  // 241 : Reserved
    EXC_RESERVED,  // 242 : Reserved
    EXC_RESERVED,  // 243 : Reserved
    EXC_RESERVED,  // 244 : Reserved
    EXC_RESERVED,  // 245 : Reserved
    EXC_RESERVED,  // 246 : Reserved
    EXC_RESERVED,  // 247 : Reserved
    EXC_RESERVED,  // 248 : Reserved
    EXC_RESERVED,  // 249 : Reserved
    EXC_RESERVED,  // 250 : Reserved
    EXC_RESERVED,  // 251 : Reserved
    EXC_RESERVED,  // 252 : Reserved
    EXC_RESERVED,  // 253 : Reserved
    EXC_RESERVED,  // 254 : Reserved
    EXC_RESERVED   // 255 : Reserved
};

//======================================================
// End of Program
//======================================================
