//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : main.c
// Function  : Main Routine
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "api.h"

//===========================================================
// Notes on GDB Stub
//===========================================================
// This program runs under Interrupt Control Mode = 2.
// During running the GDB STUB support routines,
// the interrupt level shown in EXR(CPU)  is set to 6,
// and it uses USB/UART interrupt with level 7.
// To prevent from running user's interrupt handlers in STUB,
// USER MUST USE YOUR INTERRUPT WITH LEVEL FROM 1 TO 6, ONLY.
//===========================================================

//===========
// Globals
//===========
extern sDateTime gDateTime;  // Current Clock Database

//===========================
// Main Routine
//===========================
int main(void)
{
    //---------------------------
    // Initialize System Hardware
    //---------------------------
    Init_USB();
    Init_CPG();
    Init_GPIO();
    Init_INTC();
    Init_BSC();
    Init_TMR67();
    //
    Init_SPI();
    Init_RTC();
    Init_UART();
    Init_LCD1602();
    Init_ADC();
    Init_DAC();
    Init_TMR0(0);

    //------------------
    // Clock and Touch
    //------------------
    {
        UI08 *WEEK[] = {(UI08*)"SUN", (UI08*)"MON", (UI08*)"TUE", (UI08*)"WED", (UI08*)"THU", (UI08*)"FRI", (UI08*)"SAT"};
        UI08 str0[64];
        UI08 str1[64];
        UI32 touch, touch_x, touch_y;
        UI08 sec_prev;

        sec_prev = 255;

        while(1)
        {
            if (RTC_Check_Power())
            {
                touch = TOUCH_Get_Info(&touch_x, &touch_y);
                if (touch)
                {
                    sprintf((char*) str0, "Info=(%3ld,%3ld)", touch_x, touch_y);
                    LCD1602_Print_String(0, str0);
                    //
                    touch = TOUCH_Get_Raw_Data(&touch_x, &touch_y);
                    sprintf((char*) str1, "Raw =(%3ld,%3ld)", touch_x, touch_y);
                    LCD1602_Print_String(1, str1);
                    //
                    sec_prev = 255;
                }
                else
                {
                    RTC_Get(&gDateTime);
                    if (gDateTime.bcd_seconds != sec_prev)
                    {
                        sprintf((char*) str0, "[H8SX]  %02x:%02x:%02x", gDateTime.bcd_hours, gDateTime.bcd_minutes, gDateTime.bcd_seconds);
                        sprintf((char*) str1, "20%02x/%02x/%02x (%s)", gDateTime.bcd_years, gDateTime.bcd_months, gDateTime.bcd_days, WEEK[gDateTime.weekdays - 1]);
                        LCD1602_Print_String(0, str0);
                        LCD1602_Print_String(1, str1);
                        sec_prev = gDateTime.bcd_seconds;
                    }
                }
            }
            else
            {
                LCD1602_Print_String(0, (UI08*) "[H8SX] ERROR !");
                LCD1602_Print_String(1, (UI08*) "RTC Power Fail.");
                while(1);
            }
        }
    }

    //--------------
    // End of main()
    //--------------
    return 0;
}

//===============================
// Hook for Int_Handler_TMR0_CMIA
//===============================
void Hook_Int_Handler_TMR0_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR1_CMIA
//===============================
void Hook_Int_Handler_TMR1_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR6_CMIA
//===============================
void Hook_Int_Handler_TMR6_CMIA(void)
{
    //---------------------
    // Touch Panel Control
    //---------------------
    TOUCH_Control();
}

//=========================
// Hook for Int_Handler_AD0
//=========================
void Hook_Int_Handler_AD0(void)
{
    // In this routine, do nothing
}

//======================================================
// End of Program
//======================================================

