//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : lcd_chr.c
// Function  : Control Character LCD (SC1602)
//---------------------------------------------------------
// Rev.01 2009.09.05 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "api.h"

//===============================
// Define LCD1602 Register
//===============================
#define LCD1602_IR (*volatile )
#define REG_LCD1602_TOP  0x00400000
#define REG_LCD1602_IR   (*(volatile UI08 *) (REG_LCD1602_TOP + 0x0001))
#define REG_LCD1602_DR   (*(volatile UI08 *) (REG_LCD1602_TOP + 0x0003))

//==============
// Set IR
//==============
void LCD1602_Set_IR(UI08 ir)
{
    while(TFT_Is_Active_Period());
    REG_LCD1602_IR = ir;
}

//==============
// Get IR
//==============
UI08 LCD1602_Get_IR(void)
{
    UI08 ir;

    while(TFT_Is_Active_Period());
    ir = REG_LCD1602_IR;
    return ir;
}

//==============
// Set DR
//==============
void LCD1602_Set_DR(UI08 dr)
{
    while(TFT_Is_Active_Period());
    REG_LCD1602_DR = dr;
}

//==============
// Get DR
//==============
UI08 LCD1602_Get_DR(void)
{
    UI08 dr;

    while(TFT_Is_Active_Period());
    dr = REG_LCD1602_DR;
    return dr;
}

//=====================
// Wait for Ready
//=====================
void LCD1602_Wait_Ready(void)
{
    UI08 ir;
    while(1)
    {
        ir = LCD1602_Get_IR();
        ir = ir & 0x80;
        if (ir == 0x00) break;
    }
    return;
}

//====================
// Clear Display
//====================
void LCD1602_Clear_Display(void)
{
    LCD1602_Wait_Ready();
    LCD1602_Set_IR(0x01); // CMD = Clear Display
}

//====================
// Display ON/OFF
//====================
void LCD1602_Display_ON_OFF(UI08 disp, UI08 cursor, UI08 blink)
{
    LCD1602_Wait_Ready();
    LCD1602_Set_IR(0x08 | (disp << 2) | (cursor << 1) | (blink << 0)); // CMD = Display Mode
}

//=========================
// Set Display Position
//=========================
void LCD1602_Set_Pos(UI08 posx, UI08 posy)
{
    UI08 ddram;

    posx = posx % 16;
    posy = posy %  2;
    //
    ddram = (posy << 6) | (posx << 0);
    //
    LCD1602_Wait_Ready();
    LCD1602_Set_IR(0x80 | ddram);
}

//====================================
// Set a Character on Current Position
//====================================
void LCD1602_Set_Char(UI08 ch)
{
    LCD1602_Wait_Ready();
    LCD1602_Set_DR(ch);
}

//================================
// Initialize Character LCD SC1602
//================================
void Init_LCD1602(void)
{
    volatile UI32 i;

    // Initialize as 8bit width interface (still BF not works)
    LCD1602_Set_IR(0x30); // CMD = Function Set
    // Wait for at least 4.1ms
    for (i = 0; i < (41000000 / 20); i++);
    // Initialize as 8bit width interface (still BF not works)
    LCD1602_Set_IR(0x30); // CMD = Function Set
    // Wait for at least 100us
    for (i = 0; i < (100000 / 20); i++);
    // Initialize as 8bit width interface (still BF not works)
    LCD1602_Set_IR(0x30); // CMD = Function Set
    // 8bits I/F, Display 2-lines, Font5x8
    LCD1602_Wait_Ready();
    LCD1602_Set_IR(0x38); // CMD = Function Set
    // Display Off
    LCD1602_Display_ON_OFF(0, 0, 0);
    // Clear Display
    LCD1602_Clear_Display();
    // Entry Mode
    LCD1602_Wait_Ready();
    LCD1602_Set_IR(0x06); // CMD = Entry Mode
    //
    // Display ON, Cursor OFF
    LCD1602_Display_ON_OFF(1, 0, 0);
}

//============================
// Print String on LCD1602
//============================
void LCD1602_Print_String(UI08 line, UI08 *pStr)
{
    UI08 posx;

    for (posx = 0; posx < 16; posx++)
    {
        if (*pStr != '\0')
        {
            LCD1602_Set_Pos(posx, line);
            LCD1602_Set_Char(*pStr);
            pStr++;
        }
        else // set space after NULL character
        {
            LCD1602_Set_Pos(posx, line);
            LCD1602_Set_Char(' ');
        }
    }
}

//======================================================
// End of Program
//======================================================

