/*""FILE COMMENT""************************************************************
 *	System Name	: R0K561653D000BR USB DeviceDriver Firmware
 *	File Name	: docontrol.c
 *	Version		: 1.00-070920
 *	Contents	: 
 *	Customer	: 
 *	Model		: 
 *	Order		: 
 *	CPU			: H8SX/1653F
 *	Compiler	: ch38
 *	OS			: None
 *	Programmer	: 
 *	Notes		: 
 *****************************************************************************
 * (C)2004(2006) RENESAS TECHNOLOGY CORPORATION AND RENESAS SOLUTIONS CORPORATION,
 *	 ALL RIGHTS RESERVED.
 *****************************************************************************
 *	History		: xxxx.xx.xx : Ver.0.01 ; Release
 *""FILE COMMENT END""*******************************************************/




#ifndef SysMemMap
#include	"SysMemMap.h"
#endif	/*	SysMemMap	*/

#ifndef CatProType
#include	"CatProType.h"
#endif	/*	CatProType	*/



/*	Prototype	*/
void	ActControl(unsigned long,unsigned char);
void	ActControlIn(unsigned long,unsigned char);
void	ActControlOut(unsigned long,unsigned char);
void	ActControlInOut(unsigned long,unsigned char);



/*	Contents	*/
/***************************************************************************
Function Name	:ActControl(unsigned long,unsigned char)
Working			:Executing Setup Stage in Control Transfer
Return Value	:void
Modified		:{Author : A.Ikeya	[2003.July.22]}
Modified		:{Author : A.Ikeya	[2002.Jun.28]}
Modified		:{Author : T.Ishikawa[2000.Jun.09]}
Modified		:{Author : T.Takenaga[1999.Jan.22]}
Modified		:{Author : S.Suzuki[1998.Oct.5]}
Modified		:{Author : T.Ishikawa[1998.Mar.11]}
Created			:{Author : T.Ishikawa[1997.Nov.18]}
***************************************************************************/
void	ActControl(unsigned long interruptBitStreamLVar ,unsigned char EpInfoNumberLVar) {
																	/*	Execute with received SETUP_TS interrupt	*/

	SETUP_INTF_CLEAR												/*	Clear SETUP_TS flag	*/
	CTRL_ITRF_CLEAR													/*	Clear EP0i_TR flag	*/

	FIFO_CLEAR_REGISTER = EpInfo[EpInfoNumberLVar].fifoClearEnable;	/*	Clear control-in and control-out FIFOs	*/

	EpInfo[0].PresentState = WAIT;									/*	Renewal control transfer state	*/
	contCMDGPtr.writePtr = &ep0PacketGVar.byteVal[0];
	contCMDGPtr.readPtr = &ep0PacketGVar.byteVal[0];				/*	Set read/write pointer of ringbuffer for received commands	*/

	GetPacket(&EpInfo[EpInfoNumberLVar],&contCMDGPtr);				/*	Receive setup transactions(8Byte)	*/

	DecStandardCommands();											/*	Decode received command	*/

/*------------------- end of SetUp stage -----------------------------*/

	if (EpInfo[0].PresentState == TRANS_IN) {						/*	A case of control-in data stage	*/
		/*	set EP0 interrupt enable register enable	*/
		EP0_IER_ENABLE
		/*	Disable EP0iTR	*/	
		CTRL_IN_REG_SET												/*	Disable EP0iTR(prepare control-in data stage)	*/

		/*	Execute packet transfer roution	*/
		PutPacket(&EpInfo[1],&dataBuffGPtr[0]);						/*	Prepare transmision data to USB host device	*/
	}
	else if(EpInfo[0].PresentState == TRANS_OUT){															/*	A case of control-out data stage	*/
		/*	set EP0 interrupt enable register enable	*/
		EP0_IER_ENABLE
		/*	Enable EP0iTR	*/
		CTRL_OUT_REG_SET											/*	Enable EP0iTR(prepare control-in data stage)	*/
	}
	else {
		/*	set EP0 interrupt enable register disable	*/
		EP0_IER_DISABLE
		/*	set EP0 STALL	*/
		STALL_REGISTER |= EpInfo[EpInfoNumberLVar].stallEnable;
	}
	GET_INTERRUPT_ENABLE
}

/***************************************************************************
Function Name	:ActControlInOut(unsigned long ,unsigned char)
Working			:Select Control transfer Stage
Return Value	:void
Created			:{Author : A.Ikeya	[2002.Jun.28]}
***************************************************************************/
void	ActControlInOut(unsigned long interruptBitStreamLVar ,unsigned char epInfoNumberLVar) {

	if (EpInfo[0].PresentState == TRANS_OUT) {
		epInfoNumberLVar++;
		ActControlOut(interruptBitStreamLVar,epInfoNumberLVar);
	}
	else {
		ActControlIn(interruptBitStreamLVar,epInfoNumberLVar);
	}
}



/***************************************************************************
Function Name	:ActControlIn(unsigned long, unsigned char)
Working			:Executing Data Stage and Status Stage in Control-In Transfer
Return Value	:void
Modified		:{Author : T.Ishikawa[1999.Jan.22]}
Modified		:{Author : S.Suzuki[1998.Nov.5]}
Modified		:{Author : T.Ishikawa[1998.Mar.11]}
Created			:{Author : T.Ishikawa[1997.Dec.11]}
***************************************************************************/
void	ActControlIn(unsigned long interruptBitStreamLVar ,unsigned char EpInfoNumberLVar) {
																			/*	Handle EP0o_TS , EP0i_TR , EP0i_TS interrupt in control-in state	*/

	if ((interruptBitStreamLVar & EP0_O_ACK_BITS) == EP0_O_ACK_BITS) {		/*	A case of EP0o_TS	*/

/*------------------- end of Data stage -----------------------------*/

		CTRL_IN_OTSF_CLEAR													/*	Clear EP0-related flags except SETUP_TS	*/

		EpInfo[0].PresentState = WAIT;										/*	Change present state	*/

		READ_TRIGER_REGISTER = EpInfo[EpInfoNumberLVar].getFinish;			/*	Set EP0o_Read_Complete flag	*/
		/*	Complete control transfers	*/
	}
	else {																	/*	Cases of EP0i_TS or EP0i_TR (Data stage is not finied)	*/
																			/*	Prepare transfer data again	*/

		CTRL_ITSF_CLEAR														/*	Clear EP0i_TS flag	*/

		PutPacket(&EpInfo[EpInfoNumberLVar],&dataBuffGPtr[0]);				/*	Execute packet transfer routione	*/
	}
}



/***************************************************************************
Function Name	:ActControlOut(unsigned long, unsigned char)
Working			:Executing Data Stage and Status Stage in Control-Out Transfer
Return Value	:void
Modified		:{Author : E.Ondo[2003.Oct.27]}
Modified		:{Author : A.Ikeya	[2003.July.22]}
Modified		:{Author : A.Ikeya	[2002.Oct.17]}
Modified		:{Author : T.Sekine[2001.Nov.09]}
Modified		:{Author : T.Ishikawa[1999.Jan.22]}
Modified		:{Author : S.Suzuki[1998.Nov.5]}
Modified		:{Author : T.Ishikawa[1998.Mar.11]}
Created			:{Author : T.Ishikawa[1997.Dec.11]}
***************************************************************************/
void	ActControlOut(unsigned long interruptBitStreamLVar ,unsigned char EpInfoNumberLVar) {
																				/*	Handle EP0o_TS , EP0i_TR , EP0i_TS interrupt in control-out state	*/
																				/*	Sequences:	1. Completed data transfer to host device	*/
																				/*				2. Received transfre request for sent ACK to host device	*/
																				/*				3. Completed Act transfer	*/

	enum SetCompleteType setcomplete;

/*------------------ data stage --------------------------------*/
	if ((interruptBitStreamLVar & EP0_O_ACK_BITS) == EP0_O_ACK_BITS) {			/*	A case of EP0o_TS	*/

		CTRL_OTSF_CLEAR															/*	Clear EP0o_TS flag	*/

		GetPacket(&EpInfo[EpInfoNumberLVar],&dataBuffGPtr[0]);					/*	Execute packet transfer routine	*/
	}

/*------------------ Status state ------------------------------*/

	else if ((interruptBitStreamLVar & EP0_I_ACK_BITS) != EP0_I_ACK_BITS) {	/*	EP0i_TR(transfer request)	*/


		/*	handle received data 	*/
		setcomplete = INCOMPLETE;
		setcomplete = SetControlOutContents(&transStageGPtr,&dataBuffGPtr[0]);	/*	Send received data to transStageGPtr	*/

		if (setcomplete != INCOMPLETE) {										/*	Data handling is completed	*/
			WRITE_TRIGER_REGISTER = EpInfo[EpInfoNumberLVar].putEnable;			/*	Set EP0i_PKTE (Fixed transmit data , transfer enable)	*/

			CTRL_IN_REG_SET					/*	mask EP0i_TR interrupt	*/
			GET_INTERRUPT_ENABLE

			CTRL_ITRF_CLEAR															/*	Clear EP0i_TR flag	*/
		}
		else {
			error();
		}
	}
/*------------------ end of status stage -------------------------*/
	else {																		/*	A case of EP0i_TS	*/

		CTRL_ITSF_CLEAR															/*	Clear EP0i_TS flag	*/

		EpInfo[0].PresentState = WAIT;
		/*	Complete control transfers	*/
	}
}
