//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : gpio.c
// Function  : Control GPIO
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "api.h"

//=================
// Globals
//=================
static UI08 gDDR_PA = 0x00; // Copy of DDR in PA
static UI08 gDDR_PF = 0x00; // Copy of DDR in PF
static UI08 gDDR_PM = 0x00; // Copy of DDR in PM

//==========================
// Initialize GPIO
//==========================
void Init_GPIO(void)
{
    //---------------------
    // Enable External Bus
    //---------------------
    SYSCR.BIT.EXPE = 1;
    //------------------------
    // PFC related to BSC
    //------------------------
    PFC.PFCR0.BYTE = 0x07; // CS Enable
    PFC.PFCR1.BYTE = 0x00; // Disable CS4-CS7
    PFC.PFCR2.BYTE = 0x00; // PB2=CS2, PA6(AS)=Port
    PFC.PFCR4.BYTE = 0x07; // Enable A18-A16
    PFC.PFCR6.BYTE = 0xe0; // PA4=LHWR
    PFC.PFCR8.BYTE = 0x00; // EXDMAC1 on P14-P17
    //-------------
    // P1
    //-------------
    // P10 : SPI (SCI2) TxD2 MOSI(SD/TFT/RTC)
    // P11 : SPI (SCI2) RxD2 MISO(SD/TFT/RTC)
    // P12 : SPI (SCI2) SCK2 SCK (SD/TFT/RTC)
    // P13 : SPI /CS of SD Card
    // P14 : EXDMAC /EDREQ1
    // P15 : RTC DS1305 /INT0 (input)
    // P16 : EXDMAC /EDACK1
    // P17 : TFT Back Light ON
    P1.DR.BIT.B3 = 1; // low active
    P1.DR.BIT.B7 = 1; // back light on
    P1.DDR = 0x88;
    P1.ICR.BIT.B1 = 1;
    P1.ICR.BIT.B4 = 1;
    P1.ICR.BIT.B5 = 1;
    //-------------
    // P2
    //-------------
    // P21 : TPU3 TIOCA3 TFT_HSYNC
    // P22 : TPU3 TIOCC3 TFT_VSYNC
    // P24 : TPU4 TIOCB4 TFT EXDMA Request /EDREQ1
    // P25 : TPU4 TIOCA4 TFT_DE
    // P26 : TPU5 TIOCA5 TFT_DCLK
    //-------------
    // P5
    //-------------
    // P50 : AIN0(L)
    // P51 : AIN1(R)
    // P52 : Touch Panel X1in
    // P53 : Touch Panel Y1in
    // P54 : SD Card Detect
    // P55 : SD Card Write Protect
    // P56 : AOUT0(L)
    // P57 : AOUT1(R)
    P5.ICR.BIT.B4 = 1;
    P5.ICR.BIT.B5 = 1;
    //-------------
    // P6
    //-------------
    // P60 : SCI4 TxD4
    // P61 : SCI4 RxD4
    P6.ICR.BIT.B1 = 1;
    //-------------
    // PA
    //-------------
    // PA0 : Touch panel SENSE
    // PA2 : SPI CS of RTC(DS1305)
    // PA6 : RTC DS1305 PF (input)
    PA.DR.BIT.B2 = 0; // high active
    Set_DDR_PA(Get_DDR_PA() | 0x04);
    PA.ICR.BIT.B6 = 1;
    //-------------
    // PB
    //-------------
    // PB2 : SPI /CS of LCD_QVGA
    PB.DR.BIT.B2 = 1; // low active
    PB.DDR = 0x04;
    //-------------
    // PD
    //-------------
    // BSC Address Lower
    PD.DDR = 0xff; // Enable  A7-A0 Output
    //-------------
    // PE
    //-------------
    // BSC Address Higher
    PE.DDR = 0xff; // Enable A15-A8 Output
    //-------------
    // PF
    //-------------
    // PF3 : Touch Panel X1
    // PF4 : Touch Panel X2
    //-------------
    // PH
    //-------------
    //-------------
    // PI
    //-------------
    //----------------------
    // PJ (Single Chip Mode)
    //----------------------
    //----------------------
    // PK
    //----------------------
    //-------------
    // PM
    //-------------
    // PM0 : Touch Panel Y1
    // PM1 : Touch Panel Y2
    // PM2 : TFT /CSB
    // PM3 : LED Output
    PM.DR.BIT.B2 = 1;
    PM.DR.BIT.B3 = 1; // LED off
    Set_DDR_PM(Get_DDR_PM() | 0x0c);
}

//========================
// Get DDR of PA
//========================
UI08 Get_DDR_PA(void)
{
    return gDDR_PA;
}

//========================
// Set DDR of PA
//========================
void Set_DDR_PA(UI08 ddr)
{
    PA.DDR = ddr;
    gDDR_PA = ddr;
}

//========================
// Get DDR of PF
//========================
UI08 Get_DDR_PF(void)
{
    return gDDR_PF;
}

//========================
// Set DDR of PF
//========================
void Set_DDR_PF(UI08 ddr)
{
    PF.DDR = ddr;
    gDDR_PF = ddr;
}

//========================
// Get DDR of PM
//========================
UI08 Get_DDR_PM(void)
{
    return gDDR_PM;
}

//========================
// Set DDR of PM
//========================
void Set_DDR_PM(UI08 ddr)
{
    PM.DDR = ddr;
    gDDR_PM = ddr;
}


//=============
// LED Control
//=============
void LED(UI32 control)
{
    switch(control)
    {
        case LED_OFF :
        {
            PM.DR.BIT.B3 = 1;
            break;
        }
        case LED_ON :
        {
            PM.DR.BIT.B3 = 0;
            break;
        }
        case LED_TOGGLE :
        {
            PM.DR.BIT.B3 = ~PM.DR.BIT.B3;
            break;
        }
        default : // LED_OFF
        {
            PM.DR.BIT.B3 = 1;
            break;
        }
    }
}

//==================
// LED Quick Toggle
//==================
#define LED_QUICK_CYCLE 100000
void LED_Quick_Toggle(void)
{
    volatile UI32 i;

    while(1)
    {
        LED(LED_ON);
        for (i = 0; i < LED_QUICK_CYCLE; i++);
        LED(LED_OFF);
        for (i = 0; i < LED_QUICK_CYCLE; i++);
    }
}




//======================================================
// End of Program
//======================================================
