//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : key.c
// Function  : Control Key Input
//---------------------------------------------------------
// Rev.01 2009.09.20 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include "api.h"

//==========================
// Key Chattering Wait Count
//==========================
#define KEY_CHATTERING_COUNT 10

//=======================
// Define Key Sense State
//=======================
enum KEY_STATE {KEY_IDLE, KEY_REMOVE_CHATTERING, KEY_STABLE};

//========================
// Globals for Key Control
//========================
UI08 gKey_Static_Curr_State = 0x00;
UI08 gKey_Static_Prev_State = 0x00;
UI08 gKey_Dynamic_Curr_State = 0x00;

//===========================
// Get Key Raw State
//===========================
UI08 KEY_Get_State_Raw(void)
{
    UI08 key;

    while(TFT_Is_Active_Period());
    key = *((UI08*) 0x00100001);
    key = ~key;

    return key;
}

//=====================
// Get Key Static State
//=====================
UI08 KEY_Get_Static_State(void)
{
    return gKey_Static_Curr_State;
}

//======================
// Get Key Dynamic State
//======================
UI08 KEY_Get_Dynamic_State(void)
{
    UI08 result;

    result = gKey_Dynamic_Curr_State;
    gKey_Dynamic_Curr_State = 0;
    //
    return result;
}

//=====================
// Key Sense Control
//=====================
void KEY_Sense_Control(void)
{
    static UI08 state = KEY_IDLE;
    static UI08 count = 0;
    static UI08 prev_state = 0x00;
    UI08 curr_state;

    curr_state = KEY_Get_State_Raw();
    //
    switch(state)
    {
        case KEY_IDLE :
        {
            if (curr_state != gKey_Static_Curr_State)
            {
                count = 0;
                state = KEY_REMOVE_CHATTERING;
            }
            break;
        }
        case KEY_REMOVE_CHATTERING :
        {
            if (curr_state == prev_state)
            {
                if (count >= KEY_CHATTERING_COUNT)
                {
                    gKey_Static_Prev_State = gKey_Static_Curr_State;
                    gKey_Static_Curr_State = curr_state;
                    //
                    state = KEY_STABLE;
                }
                else
                {
                    count++;
                }
            }
            else
            {
                state = KEY_IDLE;
            }
            break;
        }
        case KEY_STABLE :
        {
            if ((gKey_Static_Curr_State != 0) && (gKey_Static_Prev_State == 0))
            {
                gKey_Dynamic_Curr_State = gKey_Static_Curr_State;
            }
            //
            state = KEY_IDLE;
            break;
        }
        default :
        {
            state = KEY_IDLE;
            break;
        }
    }
    //
    prev_state = curr_state;
}

//======================================================
// End of Program
//======================================================

