//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : main.c
// Function  : Main Routine
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "api.h"

//===========================================================
// Notes on GDB Stub
//===========================================================
// This program runs under Interrupt Control Mode = 2.
// During running the GDB STUB support routines,
// the interrupt level shown in EXR(CPU)  is set to 6,
// and it uses USB/UART interrupt with level 7.
// To prevent from running user's interrupt handlers in STUB,
// USER MUST USE YOUR INTERRUPT WITH LEVEL FROM 1 TO 6, ONLY.
//===========================================================

//===========
// Globals
//===========
extern sDateTime gDateTime;  // Current Clock Database

//=============================
// Load Data from File
//=============================
UI08 *gpFile_Dst;
UI08 Load_Data(UI08 data, UI08 end)
{
    *gpFile_Dst++ = data;
    return end;
}

//=============================
// Save Data to File
//=============================
UI08 *gpFile_Src;
UI08 *gpFile_Src_End;
UI08 Save_Data(UI08 *data)
{
    UI08 end;

    *data = *gpFile_Src++;
    end = (gpFile_Src < gpFile_Src_End)? 0 : 1;

    return end;
}

//===========================
// Main Routine
//===========================
int main(void)
{
    sFrame  sFMEM;
    //---------------------------
    // Initialize System Hardware
    //---------------------------
    Init_USB();
    Init_CPG();
    Init_GPIO();
    Init_INTC();
    Init_BSC();
    Init_TMR67();
    //
    Init_SPI();
    Init_RTC();
    Init_UART();
    Init_LCD1602();
    Init_ADC();
    Init_DAC();
    Init_TMR0(0);

    //--------------------------------------
    // Initialize Frame Memory and TFT Panel
    //--------------------------------------
    Init_TFT_Panel(&sFMEM, BLU);

#if 1
    //---------------------------
    // Load File from SD Card
    //---------------------------
    {
        UI08 error;
        //
        // Setup SD Card
        //
        LCD1602_Print_String(0, (UI08*) "Load from File");
        LCD1602_Print_String(1, (UI08*) "Insert SD Card..");
        while(1)
        {
            SD_Setup_Control();
            if (SD_Check_Ready()) break;
        }
        //
        // Mount SD Card
        //
        error = SD_Mount();
        if (error)
        {
            LCD1602_Print_String(0, (UI08*) "Mount Error.");
            LCD1602_Print_String(1, (UI08*) "Please Retry.");
            while(1);
        }
        //
        // Load Image File
        //
        LCD1602_Print_String(1, (UI08*) "Loading Image...");
        //
        gpFile_Dst = (UI08*) sFMEM.ppFrame[0];
        error = Load_File_from_TargetDir((UI08*) "PICT0001RGB", (&Load_Data));
        if (error)
        {
            LCD1602_Print_String(0, (UI08*) "Load Error.");
            LCD1602_Print_String(1, (UI08*) "Please Retry.");
            while(1);
        }
        //
        // UnMount Volume
        //
        error = SD_UnMount();
        if (error)
        {
            LCD1602_Print_String(0, (UI08*) "Unmount Error.");
            LCD1602_Print_String(1, (UI08*) "Please Retry.");
            while(1);
        }
        //
        // End
        //
        LCD1602_Print_String(1, (UI08*) "Loading Done.");
        //
        CPU_Wait_N_us(1000 * 1000);
    }
#endif
#if 0
    //---------------------------
    // Save File in SD Card
    //---------------------------
    {
        UI08 error;
        UI08 new_file_name[16];
        //
        // Setup SD Card
        //
        LCD1602_Print_String(0, (UI08*) "Save to File");
        LCD1602_Print_String(1, (UI08*) "Insert SD Card..");
        while(1)
        {
            SD_Setup_Control();
            if (SD_Check_Ready()) break;
        }
        //
        // Mount SD Card
        //
        error = SD_Mount();
        if (error)
        {
            LCD1602_Print_String(0, (UI08*) "Mount Error.");
            LCD1602_Print_String(1, (UI08*) "Please Retry.");
            while(1);
        }
        //
        // Make Unique File Name
        //
        error = Make_New_File_Name_in_TargetDir(new_file_name);
        if (error)
          {
              LCD1602_Print_String(0, (UI08*) "Search Error.");
              LCD1602_Print_String(1, (UI08*) "Please Retry.");
              while(1);
          }
        //
        // Save Image File
        //
        LCD1602_Print_String(1, (UI08*) "Saving Data...");
        //
        gpFile_Src     = (UI08*) 0x00000000;
        gpFile_Src_End = (UI08*) 0x00001000; // 4KB
        //
        error = Save_File_in_TargetDir(new_file_name, (&Save_Data));
        if (error)
        {
            LCD1602_Print_String(0, (UI08*) "Save Error.");
            LCD1602_Print_String(1, (UI08*) "Please Retry.");
            while(1);
        }
        //
        // UnMount Volume
        //
        error = SD_UnMount();
        if (error)
        {
            LCD1602_Print_String(0, (UI08*) "Unmount Error.");
            LCD1602_Print_String(1, (UI08*) "Please Retry.");
            while(1);
        }
        //
        // End
        //
        LCD1602_Print_String(1, (UI08*) "Saving Done.");
        //
        CPU_Wait_N_us(1000 * 1000);
    }
#endif
    //--------------
    // Stop
    //--------------
    while(1);
    //--------------
    // End of main()
    //--------------
    return 0;
}

//===============================
// Hook for Int_Handler_TMR0_CMIA
//===============================
void Hook_Int_Handler_TMR0_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR1_CMIA
//===============================
void Hook_Int_Handler_TMR1_CMIA(void)
{
    // In this routine, do nothing
}

//===============================
// Hook for Int_Handler_TMR6_CMIA
//===============================
void Hook_Int_Handler_TMR6_CMIA(void)
{
    //------------------
    // Sense SD Card
    //------------------
    SD_Sense();
}

//=========================
// Hook for Int_Handler_AD0
//=========================
void Hook_Int_Handler_AD0(void)
{
    // In this routine, do nothing
}

//======================================================
// End of Program
//======================================================

