//=========================================================
// H8SX/1655 Project
//=========================================================
// File Name : api.h
// Function  : Application program Interface (Header)
//---------------------------------------------------------
// Rev.01 2009.08.13 Takanaga Yamazaki
//---------------------------------------------------------
// Copyright (C) 2009, 2010 Takanaga Yamazaki
//=========================================================
// ---- License Information -------------------------------
// Anyone can FREELY use this code fully or partially
// under conditions shown below.
// 1. You may use this code only for individual purpose,
//    and educational purpose.
//    Do not use this code for business even if partially.
// 2. You should use this code under the GNU GPL.
// 3. You should remain this header text in your codes
//   including Copyright credit and License Information.
// 4. Your codes should inherit this license information.
//=========================================================
// ---- Patent Notice -------------------------------------
// I have not cared whether this system (hw + sw) causes 
// infringement on the patent, copyright, trademark,
// or trade secret rights of others. You have all 
// responsibilities for determining if your designs
// and products infringe on the intellectual property
// rights of others, when you use technical information
// included in this system for your business.
//=========================================================
// ---- Disclaimers ---------------------------------------
// The function and reliability of this system are not 
// guaranteed. They may cause any damages to loss of
// properties, data, money, profits, life, or business.
// By adopting this system even partially, you assume
// all responsibility for its use.
//=========================================================

#ifndef _API_H_
#define _API_H_

#include "sys.h"

//================================
// Defines related to math.h
//================================
//------------------
// Circular Constant
//------------------
#define _PI_ (M_PI)
//----------------
// Math Function
//----------------
#define _ACOS_  acos
#define _ASIN_  asin
#define _ATAN_  atan
#define _ATAN2_ atan2
#define _CEIL_  ceil
#define _COS_   cos
#define _COSH_  cosh
#define _EXP_   exp
#define _FABS_  fabs
#define _FLOOR_ floor
#define _FMOD_  fmod
#define _FREXP_ frexp
#define _FDEXP_ fdexp
#define _LOG_   log
#define _LOG10_ log10
#define _MODF_  modf
#define _POW_   pow
#define _SIN_   sin
#define _SINH_  sinh
#define _SQRT_  sqrt
#define _TAN_   tan
#define _TANH_  tanh
#define _ATAN3_(x, y) ((_ATAN2_(x, y) >= 0)? _ATAN2_(x, y) : _ATAN2_(x, y) + 2 * _PI_)
//--------------------
// Define ABS(SI32)
//--------------------
#define _ABS_SI32_(x) (((x) >= 0)? (x) : (-(x)))

//============
// LED Control
//============
enum LED {LED_OFF, LED_ON, LED_TOGGLE};

//=================
// Pixel value
//=================
#define R_MIN (0x00)
#define R_MAX (0x1f)
#define G_MIN (0x00)
#define G_MAX (0x3f)
#define B_MIN (0x00)
#define B_MAX (0x1f)
//
#define BLK ((R_MIN << 11) + (G_MIN << 5) + (B_MIN << 0))
#define BLU ((R_MIN << 11) + (G_MIN << 5) + (B_MAX << 0))
#define GRN ((R_MIN << 11) + (G_MAX << 5) + (B_MIN << 0))
#define CYN ((R_MIN << 11) + (G_MAX << 5) + (B_MAX << 0))
#define RED ((R_MAX << 11) + (G_MIN << 5) + (B_MIN << 0))
#define MAG ((R_MAX << 11) + (G_MIN << 5) + (B_MAX << 0))
#define YEL ((R_MAX << 11) + (G_MAX << 5) + (B_MIN << 0))
#define WHT ((R_MAX << 11) + (G_MAX << 5) + (B_MAX << 0))
#define DGR ((R_MIN << 11) + ((G_MAX / 2) << 5) + ((B_MAX / 4) << 0))
#define GRY (((R_MAX / 2) << 11) + ((G_MAX / 2) << 5) + ((B_MAX / 2) << 0))

//========================
// Structure Data & Time
//========================
typedef struct
{
    UI08 bcd_seconds; // BCD Seconds (00-59)
    UI08 bcd_minutes; // BCD Minutes (00-59)
    UI08 bcd_hours;   // BCD Hours   (00-23)
    UI08 bcd_days;    // BCD Days    (01-31)
    UI08 bcd_months;  // BCD Months  (01-12)
    UI08 bcd_years;   // BCD Years   (00-99)
    UI08 weekdays;    // Weekdays 0=SUN,...,6=SAT
} sDateTime;

typedef struct
{
    UI08 year;
    UI08 month;
    UI08 date;
    UI08 week;
    UI08 hour;
    UI08 min;
    UI08 sec;
} sRTC_Data;

//===========================
// Structure Frame Memory
//===========================
typedef struct
{
    UI32 sizeX;     // horizontal pixel counts in frame memory
    UI32 sizeY;     // vertical pixel counts in frame memory
    UI16 **ppFrame; // body data of frame memory
} sFrame;

//=======================
// Structure Image Data
//=======================
typedef struct
{
    UI32 sizeX;     // horizontal size of image
    UI32 sizeY;     // vertical size of image
    UI16 **ppImage; // body data of image
} sImage;

//===========================
// Structure Button Control
//===========================
enum BUTTON {BUTTON_NOP, BUTTON_DOWN, BUTTON_UP};
typedef struct
{
    UI32 posX; // canvas coordinates of top-left corner
    UI32 posY; // canvas coordinates of top-left corner
    UI32 sizeX; // button size
    UI32 sizeY; // button size
    UI08 *pString; // button name
    UI16 color_button_off; // button color when push off
    UI16 color_button_on;  // button color when push on
    UI16 color_string_off; // string color when push off
    UI16 color_string_on;  // string color when push on
    UI32 redraw; // redraw the button
    //
    UI32 int_status; // internal use (must be initialized to 0)
} sButton;

//==================
// Tick Unit
//==================
#define TICK_UNIT (10) // ms

//==================
// Prototypes
//==================
//
// graphics.c
//
void GC_Draw_Dot(sFrame *psFrame, UI32 posX, UI32 posY, UI16 color);
UI16 GC_Get_Pixel(sFrame *psFrame, UI32 posX, UI32 posY);
void GC_Draw_Fill_Rect(sFrame *psFrame, UI32 posX, UI32 posY, UI32 sizeX, UI32 sizeY, UI16 color);
void GC_Draw_Line(sFrame *psFrame, UI32 x0, UI32 x1, UI32 y0, UI32 y1, UI16 color);
void GC_BitBit_Image(sImage *psImageSrc, sFrame *psFramedst,
                     UI32 srcXmin, UI32 srcXmax, UI32 srcYmin, UI32 srcYmax,
                     UI32 dstXmin, UI32 dstYmin,
                     UI16 pixelAdd, UI08 hasTransparent, UI16 pixelTransparent);
void GC_Draw_String(UI08 *pString, sFrame *psFrameDst,
                    UI32 posX, UI32 posY, UI16 color);
UI32 GC_Button(sButton *psButton, sFrame *psFrameDst);
//
// analog.c
//
void Init_ADC(void);
void Int_Handler_AD0(void);
void Init_DAC(void);
UI16 ADC_Get_Data(UI08 ch);
void DAC_Set_Data(UI08 ch, UI16 data);
//
// fat16.c
//
UI08 Load_File_from_TargetDir(UI08 *pFileName_11, UI08 (*Load_Data)(UI08 data, UI08 end));
UI08 Save_File_in_TargetDir(UI08 *pFileName_11, UI08 (*Save_Data)(UI08 *data));
UI08 Make_New_File_Name_in_TargetDir(UI08 *pFileName_11);
UI08 SD_Mount(void);
UI08 SD_UnMount(void);
//
// sdcard.c
//
UI08 SD_Read_Block(UI32 addr, UI08 *buffer);
UI08 SD_Write_Block(UI32 addr, UI08 *buffer);
UI08 SD_Read_Register(void);
UI08 SD_Write_CSD(void);
UI08 SD_Init(void);
void SD_Command_Argument(UI08 *command, UI32 argument);
UI08 SD_Check_Ready(void);
void SD_Setup_Control(void);
UI08 SD_Write_Command(UI08 *command);
UI08 SD_Read_Byte(void);
void SD_Write_Byte(UI08 data);
UI08 SD_Read_Socket(UI08 what);
void SD_Sense(void);
UI08 Check_SD_Insert(void);
UI08 Check_SD_Unlock(void);
//
// lcdpanel.c
//
void Init_TFT_Panel(sFrame *psFrame, UI16 color);
void TFT_SPI_Tx_Register(UI08 addr, UI08 data);
UI08 TFT_SPI_Rx_Register(UI08 addr);
void TFT_Panel_Wait_for_V_Blank_Start(void);
UI32 TFT_Is_Active_Period(void);
void Int_Handler_TPU2_TGI2B(void);
//
// dmac.c
//
void DMAC_memcpy(void *dst, void *src, UI32 bytes);
//
// touch.c
//
UI08 TOUCH_Get_Info(UI32 *touch_x, UI32 *touch_y);
UI08 TOUCH_Get_Raw_Data(UI32 *touch_x, UI32 *touch_y);
void TOUCH_Control(void);
//
// rtc.c
//
enum RTC_WEEK {SUN = 1, MON, TUE, WED, THR, FRI, SAT};
void Init_RTC(void);
void RTC_Set(sDateTime *psDateTime);
void RTC_Get(sDateTime *psDateTime);
UI08 RTC_Check_Power(void);
//
// spi.c
//
enum SPI_CS_WHICH {SPI_CS_SD, SPI_CS_TFT, SPI_CS_RTC};
enum SPI_CS_HOW   {SPI_CS_NEGATE, SPI_CS_ASSERT};
void Init_SPI(void);
void SPI_Set_BaudRate(UI32 kbps);
void SPI_Control_CS(UI08 which, UI08 how);
UI08 SPI_Bit_Reverse(UI08 in);
UI08 SPI_TxRx(UI08 byte_tx);
void SPI_Tx(UI08 byte);
UI08 SPI_Rx(void);
//
// lcd1602.c
//
void Init_LCD1602(void);
void LCD1602_Print_String(UI08 line, UI08 *pStr);
//
// key.c
//
UI08 KEY_GEt_State_Raw(void);
UI08 KEY_Get_Static_State(void);
UI08 KEY_Get_Dynamic_State(void);
void KEY_Sense_Control(void);
//
// gpio.c
//
void Init_GPIO(void);
UI08 Get_DDR_PA(void);
void Set_DDR_PA(UI08 ddr);
UI08 Get_DDR_PF(void);
void Set_DDR_PF(UI08 ddr);
UI08 Get_DDR_PM(void);
void Set_DDR_PM(UI08 ddr);
void LED(UI32 control);
void LED_Quick_Toggle(void);
//
// tmr.c
//
void Init_TMR0(UI08 cyc);
void Init_TMR1(void);
void Init_TMR67(void);
void Int_Handler_TMR0_CMIA(void);
void Int_Handler_TMR1_CMIA(void);
void Int_Handler_TMR6_CMIA(void);
UI32 TMR_Get_Ticks(void);
void TMR_Wait_One_Tick(void);
void CPU_Wait_N_us(UI32 N);
//
// bsc.c
//
void Init_BSC(void);
//
// cpg.c
//
void Init_CPG(void);

#endif // _API_H_

//=========================================================
// End of Program
//=========================================================
